{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "![Callysto.ca Banner](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-top.jpg?raw=true)\n",
    "\n",
    "<a href=\"https://hub.callysto.ca/jupyter/hub/user-redirect/git-pull?repo=https%3A%2F%2Fgithub.com%2Fcallysto%2Fcurriculum-notebooks&branch=master&subPath=Science/RadiatonAnimations/radiation-animations.ipynb&depth=1\" target=\"_parent\"><img src=\"https://raw.githubusercontent.com/callysto/curriculum-notebooks/master/open-in-callysto-button.svg?sanitize=true\" width=\"123\" height=\"24\" alt=\"Open in Callysto\"/></a>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<script>\n",
       "  function code_toggle() {\n",
       "    if (code_shown){\n",
       "      $('div.input').hide('500');\n",
       "      $('#toggleButton').val('Show Code')\n",
       "    } else {\n",
       "      $('div.input').show('500');\n",
       "      $('#toggleButton').val('Hide Code')\n",
       "    }\n",
       "    code_shown = !code_shown\n",
       "  }\n",
       "  \n",
       "  $( document ).ready(function(){\n",
       "    code_shown=false;\n",
       "    $('div.input').hide()\n",
       "  });\n",
       "</script>\n",
       "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 1,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import matplotlib.pyplot as plt\n",
    "import plotly as py\n",
    "import plotly.graph_objs as go\n",
    "import numpy as np\n",
    "import math\n",
    "import ipywidgets as widgets\n",
    "from IPython.display import display, Math, Latex, HTML, IFrame\n",
    "from astropy.table import Table, Column\n",
    "from ipywidgets import interact, interactive\n",
    "\n",
    "py.offline.init_notebook_mode(connected=True)\n",
    "%matplotlib inline\n",
    "\n",
    "font = {'family' : 'sans-serif',\n",
    "        'weight' : 'normal',\n",
    "        'size'   : 14}\n",
    "\n",
    "plt.rc('font', **font)\n",
    "\n",
    "utils_code = \"\"\"\n",
    "class TextBox {\n",
    "  PVector location;\n",
    "  PVector velocity;\n",
    "  \n",
    "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    location = new PVector(x_loc, y_loc);\n",
    "    velocity = new PVector(x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  void update() {\n",
    "    location.add(velocity);\n",
    "  }\n",
    "  \n",
    "  void display(String message, int size, float[] col) {\n",
    "    textSize(size);\n",
    "    fill(col[0],col[1],col[2]);\n",
    "    text(message, location.x, location.y);\n",
    "  }\n",
    "}\n",
    "\n",
    "class Mover {\n",
    "  PVector location;\n",
    "  PVector velocity;\n",
    "  \n",
    "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
    "    location = new PVector(x_loc, y_loc);\n",
    "    velocity = new PVector(x_vel, y_vel);\n",
    "  }\n",
    "  \n",
    "  void update() {\n",
    "    location.add(velocity);\n",
    "  }\n",
    "}\n",
    "\n",
    "class Gamma extends Mover {\n",
    "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  //creates squiggly lines for a gamma ray\n",
    "  float[] twoLines(float x_val, float y_val, int i) {\n",
    "    //upwards gamma\n",
    "    if (i == 1) {\n",
    "      // return the coordinates of two perpendicular lines\n",
    "      float[][] coords = {\n",
    "        { x_val, y_val, x_val+3, y_val-10 },\n",
    "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
    "      };\n",
    "\n",
    "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
    "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
    "\n",
    "      float[] end = { coords[1][2], coords[1][3] };\n",
    "      return end;\n",
    "    } else {\n",
    "      float[][] coords = {\n",
    "        { x_val, y_val, x_val+3, y_val+10 },\n",
    "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
    "      };\n",
    "\n",
    "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
    "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
    "\n",
    "      float[] end = {coords[1][2], coords[1][3]};\n",
    "      return end;\n",
    "    }\n",
    "  }\n",
    "\n",
    "  void drawArrow(float cx, float cy, int len, float angle) {\n",
    "    pushMatrix();\n",
    "    translate(cx, cy);\n",
    "    rotate(radians(angle));\n",
    "    line(0, 0, len, 0);\n",
    "    line(len, 0, len-8, -8);\n",
    "    line(len, 0, len-8, 8);\n",
    "    popMatrix();\n",
    "  }\n",
    "  \n",
    "  void display(int i, int angle) {\n",
    "    stroke(255, 0, 0);\n",
    "    float[] x = twoLines(location.x, location.y, i);\n",
    "    float[] y = twoLines(x[0], x[1], i);\n",
    "    float[] z = twoLines(y[0], y[1], i);\n",
    "    drawArrow(z[0], z[1], 10, angle);\n",
    "  }\n",
    "}\n",
    "\n",
    "float[][] position(float x_val, float y_val, float radius) {\n",
    "  // make it produce the x and y coordinates for the 6 spots around it\n",
    "  float y_dist = sin(radians(30)) * 2 * radius;\n",
    "  float x_dist = cos(radians(30)) * 2 * radius;\n",
    "  \n",
    "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
    "  float[][] coords = {\n",
    "    { x_val, y_val-(2*radius) },\n",
    "    { x_val+x_dist, y_val-y_dist },\n",
    "    { x_val+x_dist, y_val+y_dist },\n",
    "    { x_val, y_val+(2*radius) },\n",
    "    { x_val-x_dist, y_val+y_dist },\n",
    "    { x_val-x_dist, y_val-y_dist }\n",
    "  };\n",
    "  \n",
    "  return coords;\n",
    "}\n",
    "\n",
    "boolean isItemInArray(float[][] array, float[] item) {\n",
    "    for (int i = 0; i < array.length; i++) {\n",
    "        // This if statement depends on the format of your array\n",
    "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
    "            return true;   // Found it\n",
    "        }\n",
    "    }\n",
    "    return false;   // Not found\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "'''Above, we are importing all the necessary modules in order to run the notebook. \n",
    "Numpy allows us to define arrays of values for our variables to plot them\n",
    "matplotlib is what we use to create the figures\n",
    "the display and widgets are to make the notebook look neat\n",
    "'''\n",
    "\n",
    "HTML('''<script>\n",
    "  function code_toggle() {\n",
    "    if (code_shown){\n",
    "      $('div.input').hide('500');\n",
    "      $('#toggleButton').val('Show Code')\n",
    "    } else {\n",
    "      $('div.input').show('500');\n",
    "      $('#toggleButton').val('Hide Code')\n",
    "    }\n",
    "    code_shown = !code_shown\n",
    "  }\n",
    "  \n",
    "  $( document ).ready(function(){\n",
    "    code_shown=false;\n",
    "    $('div.input').hide()\n",
    "  });\n",
    "</script>\n",
    "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>''')\n",
    "        \n",
    "    "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Nuclear Radiation: Alpha, Beta, and Gamma\n",
    "\n",
    "<img src=\"https://media.giphy.com/media/3bvICesX0yIfu/giphy.gif\" alt=\"Drawing\" style=\"width: 750px;\"/>\n",
    "\n",
    "<center>Gif from [Giphy](https://giphy.com/gifs/hypnotic-3bvICesX0yIfu), June 20th, 2018.</center>\n",
    "\n",
    "Figure 1: Here we see a sample of uranium undergoing radioactive decay inside a cloud chamber. The lines shooting out from the sample are made by fast moving charged particles ejected by the uranium. A cloud chamber such as this allows us to see how radiation can interact with its surroundings. Check out [this link](https://www.sciencealert.com/watch-uranium-emits-radiation-inside-cloud-chamber) for more info on cloud chambers."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Introduction\n",
    "\n",
    "The term \"radiation\" can be used to describe a broad spectrum of physical phenomena. Generally speaking, **radiation** refers to the emission of energy from a source in the form of either a wave, or a particle, and the ways in which these emissions are generated can vary significantly. \n",
    "\n",
    "In our daily lives, we interact with many forms of **electromagnetic radiation** (EMR) without a second thought, whether it be radio, microwave, infrared or visible light. However, there are other forms of radiation that may be less noticeable to the average person. \n",
    "\n",
    "In this notebook we will talk about three types of **nuclear radiation**: **alpha radiation, beta radiation, and gamma radiation**. We will talk about how these types of radiation are generated, how they interact with nature and their surroundings, and some of their useful applications. The analysis of various types of radiation can provide scientists with new ways to understand how the universe operates, and can result in previously unknown applications that make our lives easier."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Background\n",
    "\n",
    "Let's begin by outlining the general difference between wave radiation and particle radiation.\n",
    "\n",
    "### Wave Radiation\n",
    "\n",
    "All wave type radiation is classified as EMR. Electromagnetic radiation can be described as an interplay between electric and magnetic fields, with each oscillating along planes that are perpendicular to one another. Take a look at the gif below for a better visualization of this phenomenon:\n",
    "\n",
    "<img src=\"http://www.ariel.ac.il/sites/cezar/ariel/ANIMATIONS/images/wave_movie.gif\" alt=\"Drawing\" style=\"width: 500px;\"/>\n",
    "<center>Image from http://www.ariel.ac.il/sites/cezar/ariel/ANIMATIONS/physics3.html</center>\n",
    "<center> Figure 2: As the name suggests, electromagnetic waves consist of both electric and magnetic fields that propagate perpendicularly to one another. </center>\n",
    " \n",
    "\n",
    "These waves are usually generated through interactions between subatomic particles within an atom. For example, visible light can be created when an electron changes energy levels within an atom. When an electron moves from a higher energy orbital to a lower energy orbital, the difference in energy is released as electromagnetic radiation. Take a look at the animation below that demonstrates how visible light can be generated within a hydrogen atom.\n",
    "\n",
    "Click on the hydrogen atom to run the animation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "scrolled": true,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
       "<script type=\"text/javascript\">\n",
       "  var processingCode = `\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "class HydrogenMover extends Mover {\n",
       "  float rad;\n",
       "  \n",
       "  HydrogenMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "    rad = 0.02;\n",
       "  }\n",
       "  \n",
       "  void update(int dist) {\n",
       "    location.x = 350 + sin(rad)*(dist);\n",
       "    location.y = 100 + cos(rad)*(dist);\n",
       "    rad = rad + 0.02;\n",
       "  }\n",
       "  \n",
       "  void display(int i, int rad) {\n",
       "    stroke(0);\n",
       "\n",
       "    //red\n",
       "    if (i == 0) {\n",
       "      fill(255, 0, 0);\n",
       "    } else if (i == 1) {\n",
       "      fill(12, 48, 224);\n",
       "    } else if (i == 2) {\n",
       "      fill(255, 255, 255);\n",
       "    }\n",
       "\n",
       "    ellipse(location.x, location.y, rad, rad);\n",
       "  }\n",
       "}\n",
       "\n",
       "// Implementations are identical so using inheritance to \"alias\" Gamma\n",
       "class Photon extends Gamma {\n",
       "  Photon(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "}\n",
       "\n",
       "int x = 0;\n",
       "\n",
       "void mousePressed() {\n",
       "  if (x == 0) {\n",
       "    x = 1;\n",
       "  } \n",
       "}\n",
       "\n",
       "void setup() {\n",
       "  size(700,200);\n",
       "}\n",
       "\n",
       "//create stationary proton\n",
       "HydrogenMover proton = new HydrogenMover(350,100,0,0);\n",
       "//create electron\n",
       "HydrogenMover electron = new HydrogenMover(350,50,0,0);\n",
       "\n",
       "HydrogenMover n3 = new HydrogenMover(350,100,0,0);\n",
       "HydrogenMover n2 = new HydrogenMover(350,100,0,0);\n",
       "\n",
       "Photon red = new Photon(350,100,2,0.5);\n",
       "\n",
       "//create text for energy levels\n",
       "\n",
       "// create text for n = 3\n",
       "float n3x_loc = 420;\n",
       "float n3y_loc = 100;\n",
       "float n3x_vel = 0;\n",
       "float n3y_vel = 0;\n",
       "String n3_message = \"n = 3\";\n",
       "int n3_size = 12;\n",
       "float[] n3_col = {0,0,0};\n",
       "TextBox n3_text = new TextBox(n3x_loc,n3y_loc, n3x_vel, n3y_vel);\n",
       "\n",
       "// create text for n = 2\n",
       "float n2x_loc = 375;\n",
       "float n2y_loc = 100;\n",
       "float n2x_vel = 0;\n",
       "float n2y_vel = 0;\n",
       "String n2_message = \"n = 2\";\n",
       "int n2_size = 12;\n",
       "float[] n2_col = {0,0,0};\n",
       "TextBox n2_text = new TextBox(n2x_loc,n2y_loc, n2x_vel, n2y_vel);\n",
       "\n",
       "void draw() {\n",
       "  background(255);\n",
       "  textSize(24);\n",
       "  fill(0);\n",
       "  text(\"Electron Transition in Hydrogen Atom\", 145, 30);\n",
       "  \n",
       "  textSize(24);\n",
       "  \n",
       "  if (x == 1) {\n",
       "    //shift electron to n = 2, emit light\n",
       "    n3.display(2,120);\n",
       "    n2.display(2,40);\n",
       "    n2_text.display(n2_message, n2_size,n2_col);\n",
       "    proton.display(1,16);\n",
       "    electron.display(0,8);\n",
       "    electron.update(20);\n",
       "    red.display(0,20);\n",
       "    red.update();\n",
       "  } else {\n",
       "    //make electron orbit around n = 3\n",
       "    n3.display(2,120);\n",
       "    n3_text.display(n3_message, n3_size,n3_col);\n",
       "    n2.display(2,40);\n",
       "    proton.display(1,16);\n",
       "    electron.display(0,8);\n",
       "    electron.update(60);\n",
       "  }\n",
       "}\n",
       "`;\n",
       "  var myCanvas = document.getElementById(\"canvas1\");\n",
       "  var jsCode = Processing.compile(processingCode);\n",
       "  var processingInstance = new Processing(myCanvas, jsCode);\n",
       " </script>\n",
       "<canvas id=\"canvas1\"> </canvas>    \n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 2,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "hydrogen_code = \"\"\"\n",
    "class TextBox {\n",
    "  PVector location;\n",
    "  PVector velocity;\n",
    "  \n",
    "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    location = new PVector(x_loc, y_loc);\n",
    "    velocity = new PVector(x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  void update() {\n",
    "    location.add(velocity);\n",
    "  }\n",
    "  \n",
    "  void display(String message, int size, float[] col) {\n",
    "    textSize(size);\n",
    "    fill(col[0],col[1],col[2]);\n",
    "    text(message, location.x, location.y);\n",
    "  }\n",
    "}\n",
    "\n",
    "class Mover {\n",
    "  PVector location;\n",
    "  PVector velocity;\n",
    "  \n",
    "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
    "    location = new PVector(x_loc, y_loc);\n",
    "    velocity = new PVector(x_vel, y_vel);\n",
    "  }\n",
    "  \n",
    "  void update() {\n",
    "    location.add(velocity);\n",
    "  }\n",
    "}\n",
    "\n",
    "class Gamma extends Mover {\n",
    "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  //creates squiggly lines for a gamma ray\n",
    "  float[] twoLines(float x_val, float y_val, int i) {\n",
    "    //upwards gamma\n",
    "    if (i == 1) {\n",
    "      // return the coordinates of two perpendicular lines\n",
    "      float[][] coords = {\n",
    "        { x_val, y_val, x_val+3, y_val-10 },\n",
    "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
    "      };\n",
    "\n",
    "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
    "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
    "\n",
    "      float[] end = { coords[1][2], coords[1][3] };\n",
    "      return end;\n",
    "    } else {\n",
    "      float[][] coords = {\n",
    "        { x_val, y_val, x_val+3, y_val+10 },\n",
    "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
    "      };\n",
    "\n",
    "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
    "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
    "\n",
    "      float[] end = {coords[1][2], coords[1][3]};\n",
    "      return end;\n",
    "    }\n",
    "  }\n",
    "\n",
    "  void drawArrow(float cx, float cy, int len, float angle) {\n",
    "    pushMatrix();\n",
    "    translate(cx, cy);\n",
    "    rotate(radians(angle));\n",
    "    line(0, 0, len, 0);\n",
    "    line(len, 0, len-8, -8);\n",
    "    line(len, 0, len-8, 8);\n",
    "    popMatrix();\n",
    "  }\n",
    "  \n",
    "  void display(int i, int angle) {\n",
    "    stroke(255, 0, 0);\n",
    "    float[] x = twoLines(location.x, location.y, i);\n",
    "    float[] y = twoLines(x[0], x[1], i);\n",
    "    float[] z = twoLines(y[0], y[1], i);\n",
    "    drawArrow(z[0], z[1], 10, angle);\n",
    "  }\n",
    "}\n",
    "\n",
    "float[][] position(float x_val, float y_val, float radius) {\n",
    "  // make it produce the x and y coordinates for the 6 spots around it\n",
    "  float y_dist = sin(radians(30)) * 2 * radius;\n",
    "  float x_dist = cos(radians(30)) * 2 * radius;\n",
    "  \n",
    "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
    "  float[][] coords = {\n",
    "    { x_val, y_val-(2*radius) },\n",
    "    { x_val+x_dist, y_val-y_dist },\n",
    "    { x_val+x_dist, y_val+y_dist },\n",
    "    { x_val, y_val+(2*radius) },\n",
    "    { x_val-x_dist, y_val+y_dist },\n",
    "    { x_val-x_dist, y_val-y_dist }\n",
    "  };\n",
    "  \n",
    "  return coords;\n",
    "}\n",
    "\n",
    "boolean isItemInArray(float[][] array, float[] item) {\n",
    "    for (int i = 0; i < array.length; i++) {\n",
    "        // This if statement depends on the format of your array\n",
    "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
    "            return true;   // Found it\n",
    "        }\n",
    "    }\n",
    "    return false;   // Not found\n",
    "}\n",
    "class HydrogenMover extends Mover {\n",
    "  float rad;\n",
    "  \n",
    "  HydrogenMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "    rad = 0.02;\n",
    "  }\n",
    "  \n",
    "  void update(int dist) {\n",
    "    location.x = 350 + sin(rad)*(dist);\n",
    "    location.y = 100 + cos(rad)*(dist);\n",
    "    rad = rad + 0.02;\n",
    "  }\n",
    "  \n",
    "  void display(int i, int rad) {\n",
    "    stroke(0);\n",
    "\n",
    "    //red\n",
    "    if (i == 0) {\n",
    "      fill(255, 0, 0);\n",
    "    } else if (i == 1) {\n",
    "      fill(12, 48, 224);\n",
    "    } else if (i == 2) {\n",
    "      fill(255, 255, 255);\n",
    "    }\n",
    "\n",
    "    ellipse(location.x, location.y, rad, rad);\n",
    "  }\n",
    "}\n",
    "\n",
    "// Implementations are identical so using inheritance to \"alias\" Gamma\n",
    "class Photon extends Gamma {\n",
    "  Photon(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "}\n",
    "\n",
    "int x = 0;\n",
    "\n",
    "void mousePressed() {\n",
    "  if (x == 0) {\n",
    "    x = 1;\n",
    "  } \n",
    "}\n",
    "\n",
    "void setup() {\n",
    "  size(700,200);\n",
    "}\n",
    "\n",
    "//create stationary proton\n",
    "HydrogenMover proton = new HydrogenMover(350,100,0,0);\n",
    "//create electron\n",
    "HydrogenMover electron = new HydrogenMover(350,50,0,0);\n",
    "\n",
    "HydrogenMover n3 = new HydrogenMover(350,100,0,0);\n",
    "HydrogenMover n2 = new HydrogenMover(350,100,0,0);\n",
    "\n",
    "Photon red = new Photon(350,100,2,0.5);\n",
    "\n",
    "//create text for energy levels\n",
    "\n",
    "// create text for n = 3\n",
    "float n3x_loc = 420;\n",
    "float n3y_loc = 100;\n",
    "float n3x_vel = 0;\n",
    "float n3y_vel = 0;\n",
    "String n3_message = \"n = 3\";\n",
    "int n3_size = 12;\n",
    "float[] n3_col = {0,0,0};\n",
    "TextBox n3_text = new TextBox(n3x_loc,n3y_loc, n3x_vel, n3y_vel);\n",
    "\n",
    "// create text for n = 2\n",
    "float n2x_loc = 375;\n",
    "float n2y_loc = 100;\n",
    "float n2x_vel = 0;\n",
    "float n2y_vel = 0;\n",
    "String n2_message = \"n = 2\";\n",
    "int n2_size = 12;\n",
    "float[] n2_col = {0,0,0};\n",
    "TextBox n2_text = new TextBox(n2x_loc,n2y_loc, n2x_vel, n2y_vel);\n",
    "\n",
    "void draw() {\n",
    "  background(255);\n",
    "  textSize(24);\n",
    "  fill(0);\n",
    "  text(\"Electron Transition in Hydrogen Atom\", 145, 30);\n",
    "  \n",
    "  textSize(24);\n",
    "  \n",
    "  if (x == 1) {\n",
    "    //shift electron to n = 2, emit light\n",
    "    n3.display(2,120);\n",
    "    n2.display(2,40);\n",
    "    n2_text.display(n2_message, n2_size,n2_col);\n",
    "    proton.display(1,16);\n",
    "    electron.display(0,8);\n",
    "    electron.update(20);\n",
    "    red.display(0,20);\n",
    "    red.update();\n",
    "  } else {\n",
    "    //make electron orbit around n = 3\n",
    "    n3.display(2,120);\n",
    "    n3_text.display(n3_message, n3_size,n3_col);\n",
    "    n2.display(2,40);\n",
    "    proton.display(1,16);\n",
    "    electron.display(0,8);\n",
    "    electron.update(60);\n",
    "  }\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "html_template = \"\"\"\n",
    "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
    "<script type=\"text/javascript\">\n",
    "  var processingCode = `{}`;\n",
    "  var myCanvas = document.getElementById(\"canvas1\");\n",
    "  var jsCode = Processing.compile(processingCode);\n",
    "  var processingInstance = new Processing(myCanvas, jsCode);\n",
    " </script>\n",
    "<canvas id=\"canvas1\"> </canvas>    \n",
    "\"\"\"\n",
    "\n",
    "html_code = html_template.format(utils_code+hydrogen_code)\n",
    "HTML(html_code)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<center> Figure 3: The electron in the hydrogen atom changes from the $n = 3$ energy level to the $n = 2$ energy level. This transition results in the emission of a red photon.</center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Other high energy interactions within an atom will create waves with higher energy, and vice-versa. Later on, we will talk about some of the high energy processes that create gamma rays.\n",
    "\n",
    "### Particle Radiation\n",
    "\n",
    "On the other hand, particle radiation consists of one or more solid particles being ejected from an atom. These ejections can arise from the **radioactive decay** of an unstable nuclei, or from a reaction between two separate nuclei, such as a particle collision, or a fission/fusion reaction. \n",
    "\n",
    "The term **radioactive decay** refers to the process whereby a large atomic nucleus breaks down into a smaller, more stable nucleus. Radioactive decay occurs when the forces holding the nucleus together (the strong and weak nuclear forces) become overwhelmed by the forces pulling it apart. When this happens, the nucleus will eject one or many particles in order to become smaller, and more stable.\n",
    "\n",
    "Reactions such as **nuclear fission** and **nuclear fusion** can also create particle radiation. **Nuclear fission** is a type of nuclear reaction wherein the nucleus of an atom is forcibly split into two smaller nuclei, and **nuclear fusion** is the reverse: two smaller nuclei combine to form one larger nucleus. These processes require extreme conditions, vast amounts of energy, and can produce many different types of particle and wave radiation as a byproduct.  We won't go into much more detail about these processes, but here is a link to information on fission and fusion if you are interested: https://nuclear.duke-energy.com/2013/01/30/fission-vs-fusion-whats-the-difference.\n",
    "\n",
    "In either case, whether it be a nuclear reaction or radioactive decay, one or many subatomic particles (protons, neutrons, electrons, neutrinos etc.) may be sent flying away from an atom at a high velocity. By recognizing the particles that have been ejected, and by measuring the energy that they carry, scientists are able to determine the source of the radiation and the processes that caused it. \n",
    "\n",
    "\n",
    "<img src=\"http://static.messynessychic.com/wp-content/uploads/2017/01/neil-degrasse-tyson-super-k-.jpg\" alt=\"Drawing\" style=\"width: 750px;\"/>\n",
    "<center>Image from http://www.messynessychic.com/2017/01/13/journey-to-the-centre-of-the-earth-in-a-rubber-dingy</center>\n",
    "<center> Figure 4: Here we see Dr. Neil deGrasse Tyson inside the Super-Kamiokande Neutrino Detector in Japan. This incredibly sensitive device recognizes neutrino radiation coming from across the universe, and measures their energy and trajectory to provide information on the objects that have sent them to us. </center>\n",
    "\n",
    "\n",
    "## Dangers of Radiation\n",
    "\n",
    "Whether it be from sci-fi movies or real life threats of nuclear war, you are probably familiar with the potential devastation that comes from certain forms of radiation. With all of this information, you may be wondering: how are invisible waves and tiny particles so dangerous? Well, the danger arises from the potential for radiation to ionize other atoms that they come into contact with. \n",
    "\n",
    "When atoms within a biological cell are ionized, the functionality of the cell can be disrupted. The cell may repair itself improperly, or die altogether. When this happens on an acute level, many health issues can arise, including cancer. Both particle and wave radiation have the potential to ionize atoms, but some forms of radiation are more dangerous than others, as we will see in the sections below.\n",
    "\n",
    "\n",
    "Now that you are more familiar with the differences between particle and wave radiation, let's get into the details of alpha, beta, and gamma radiation.\n",
    "    \n",
    "    "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Alpha ($\\alpha$) Radiation\n",
    "\n",
    "**Alpha radiation**, also known as **alpha decay**, occurs when a large unstable atomic nucleus radioactively decays and ejects an **alpha particle**. An alpha particle consists of two neutrons and two protons, and is identical to the nucleus of a helium-4 atom."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Creation\n",
    "The nucleus of an atom consists of protons and neutrons, which are bound together by the **strong nuclear force**. This force is very strong over small distances, but it is constantly in competition with the electromagnetic repulsion between the positively charged protons within the nucleus. \n",
    "\n",
    "In a large nucleus, the strong nuclear force can become overwhelmed by these electromagnetic repulsions, leading to the ejection of an alpha particle. By ejecting two protons and two neutrons, the nucleus loses two units of charge and the electromagnetic repulsions decrease in strength, lending more stability to the nucleus.\n",
    "\n",
    "After the nucleus ejects the alpha particle, it becomes an element with an atomic number two less, and an atomic mass four less than the original atom.\n",
    "\n",
    "Click on the nucleus to run the animation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
       "<script type=\"text/javascript\">\n",
       "  var processingCode = `\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "\n",
       "class AlphaMover extends Mover {\n",
       "  AlphaMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void display(int i) {\n",
       "    stroke(0);\n",
       "\n",
       "    if (i % 2 == 0) {\n",
       "      fill(175);\n",
       "    } else {\n",
       "      fill(12,48,224);\n",
       "    }\n",
       "\n",
       "    ellipse(location.x, location.y, 16, 16);\n",
       "  }\n",
       "}\n",
       "\n",
       "AlphaMover[] movers = {};\n",
       "\n",
       "void addMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "  movers = (AlphaMover[])append(movers, new AlphaMover(x_loc, y_loc, x_vel, y_vel));\n",
       "}\n",
       "\n",
       "void setup() {\n",
       "  size(700, 200);\n",
       "  float[] center = {100.0, 100.0};\n",
       "  float[][] all_coords = {};\n",
       "  float[][] orig_coords = position(center[0], center[1], 8.0);\n",
       "  \n",
       "  //from the center, make 6 coords\n",
       "  float[][] coords = position(center[0], center[1], 8.0);\n",
       "\n",
       "  //make 6 particles\n",
       "  for (int k = 0; k < 6; k++) {\n",
       "    //if coords do not yet exist, make the circle, else, don't\n",
       "    if (!isItemInArray(all_coords, coords[k])) {\n",
       "      //create the mover\n",
       "      // add the mover to the movers list\n",
       "      addMover(coords[k][0], coords[k][1], 0, 0);\n",
       "      \n",
       "      //add coords to the list\n",
       "      all_coords = (float[][])append(all_coords, coords[k]);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  //now change the center and make new circles\n",
       "  for (int i = 0; i < 6; i++) {\n",
       "    //redefine the center \n",
       "    center[0] = orig_coords[i][0];\n",
       "    center[1] = orig_coords[i][1];\n",
       "\n",
       "    //from the center, make 6 coords\n",
       "    float[][] new_coords = position(center[0], center[1], 8.0);\n",
       "\n",
       "    //make 6 particles\n",
       "    for (int k = 0; k < 6; k++) {\n",
       "      //if coords do not yet exist, make the circle, else, don't\n",
       "      if (!isItemInArray(all_coords, new_coords[k])) {\n",
       "        //create the mover\n",
       "        // add the mover to the movers list\n",
       "        addMover(new_coords[k][0], new_coords[k][1], 0, 0);\n",
       "\n",
       "        //add coords to the list\n",
       "        all_coords = (float[][])append(all_coords, new_coords[k]);\n",
       "      }\n",
       "    }\n",
       "  }\n",
       "}\n",
       "\n",
       "AlphaMover[] make_alpha() {\n",
       "  // each mouse click, eject an alpha particle\n",
       "  AlphaMover[] alphas = {};\n",
       "  float[] center = {100.0,100.0};\n",
       "  \n",
       "  //will use 0, 1, 2\n",
       "  float[][] coords = position(center[0],center[1],8.0);\n",
       "  float[][] get_center = position(coords[0][0],coords[0][1],8.0);\n",
       "  //and this coord\n",
       "  float[][] center_coord = {{get_center[3][0],get_center[3][1]}};\n",
       "  \n",
       "  float[][] alpha_coords = {};\n",
       "  for (int k = 0; k < 3; k++) {\n",
       "    alpha_coords = (float[][])append(alpha_coords,coords[k]);\n",
       "  }\n",
       "  alpha_coords = (float[][])append(alpha_coords,center_coord[0]);\n",
       "  \n",
       "  //alpha coords is now the list of coordinates for the alpha particle\n",
       "  for (int k = 0; k < 4; k++) {\n",
       "    alphas = (AlphaMover[])append(alphas,new AlphaMover(alpha_coords[k][0],alpha_coords[k][1],2,0));\n",
       "  }\n",
       "  return alphas;\n",
       "}\n",
       "\n",
       "// create text for alpha\n",
       "float ax_loc = 50;\n",
       "float ay_loc = 135;\n",
       "float ax_vel = 0.5;\n",
       "float ay_vel = 0;\n",
       "String a_message = \"Alpha Particle\";\n",
       "int a_size = 18;\n",
       "float[] a_col = {9,49,245};\n",
       "TextBox alpha_text = new TextBox(ax_loc,ay_loc, ax_vel, ay_vel);\n",
       "\n",
       "// create the alpha particle\n",
       "AlphaMover[] alphas = make_alpha();\n",
       "\n",
       "int x = 0;\n",
       "void mousePressed() {\n",
       "  if (x == 0) {\n",
       "    x = 1;\n",
       "  } \n",
       "}\n",
       "\n",
       "void draw() {\n",
       "  background(255);\n",
       "  textSize(32);\n",
       "  fill(0);\n",
       "  text(\"Alpha Decay\", 260, 30);\n",
       "  \n",
       "  textSize(24);\n",
       "  \n",
       "  if (x == 1) {\n",
       "    for (int i = 0; i < alphas.length; i++) {\n",
       "      alphas[i].update();\n",
       "      alphas[i].display(i);\n",
       "      //draw alpha text\n",
       "      alpha_text.update();\n",
       "      alpha_text.display(a_message, a_size, a_col);\n",
       "    }\n",
       "    for (int i = 0; i < (movers.length - 4); i++) {\n",
       "      movers[i].update();\n",
       "      //movers[i].checkEdges();\n",
       "      movers[i].display(i);\n",
       "    }\n",
       "    fill(9, 49, 245);\n",
       "    text(\"Protons - 7\", 20, 170);\n",
       "    fill(96, 97, 100);\n",
       "    text(\"Neutrons - 8\", 20, 190);\n",
       "  } else {\n",
       "      for (int i = 0; i < movers.length; i++) {\n",
       "        movers[i].update();\n",
       "        //movers[i].checkEdges();\n",
       "        movers[i].display(i);\n",
       "      }\n",
       "    fill(9, 49, 245);\n",
       "    text(\"Protons - 9\", 20, 170);\n",
       "    fill(96, 97, 100);\n",
       "    text(\"Neutrons - 10\", 20, 190);\n",
       "  }\n",
       "}\n",
       "`;\n",
       "  var myCanvas = document.getElementById(\"canvas2\");\n",
       "  var jsCode = Processing.compile(processingCode);\n",
       "  var processingInstance = new Processing(myCanvas, jsCode);\n",
       " </script>\n",
       "<canvas id=\"canvas2\"> </canvas>    \n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alpha_code = \"\"\"\n",
    "class AlphaMover extends Mover {\n",
    "  AlphaMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  void display(int i) {\n",
    "    stroke(0);\n",
    "\n",
    "    if (i % 2 == 0) {\n",
    "      fill(175);\n",
    "    } else {\n",
    "      fill(12,48,224);\n",
    "    }\n",
    "\n",
    "    ellipse(location.x, location.y, 16, 16);\n",
    "  }\n",
    "}\n",
    "\n",
    "AlphaMover[] movers = {};\n",
    "\n",
    "void addMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "  movers = (AlphaMover[])append(movers, new AlphaMover(x_loc, y_loc, x_vel, y_vel));\n",
    "}\n",
    "\n",
    "void setup() {\n",
    "  size(700, 200);\n",
    "  float[] center = {100.0, 100.0};\n",
    "  float[][] all_coords = {};\n",
    "  float[][] orig_coords = position(center[0], center[1], 8.0);\n",
    "  \n",
    "  //from the center, make 6 coords\n",
    "  float[][] coords = position(center[0], center[1], 8.0);\n",
    "\n",
    "  //make 6 particles\n",
    "  for (int k = 0; k < 6; k++) {\n",
    "    //if coords do not yet exist, make the circle, else, don't\n",
    "    if (!isItemInArray(all_coords, coords[k])) {\n",
    "      //create the mover\n",
    "      // add the mover to the movers list\n",
    "      addMover(coords[k][0], coords[k][1], 0, 0);\n",
    "      \n",
    "      //add coords to the list\n",
    "      all_coords = (float[][])append(all_coords, coords[k]);\n",
    "    }\n",
    "  }\n",
    "\n",
    "  //now change the center and make new circles\n",
    "  for (int i = 0; i < 6; i++) {\n",
    "    //redefine the center \n",
    "    center[0] = orig_coords[i][0];\n",
    "    center[1] = orig_coords[i][1];\n",
    "\n",
    "    //from the center, make 6 coords\n",
    "    float[][] new_coords = position(center[0], center[1], 8.0);\n",
    "\n",
    "    //make 6 particles\n",
    "    for (int k = 0; k < 6; k++) {\n",
    "      //if coords do not yet exist, make the circle, else, don't\n",
    "      if (!isItemInArray(all_coords, new_coords[k])) {\n",
    "        //create the mover\n",
    "        // add the mover to the movers list\n",
    "        addMover(new_coords[k][0], new_coords[k][1], 0, 0);\n",
    "\n",
    "        //add coords to the list\n",
    "        all_coords = (float[][])append(all_coords, new_coords[k]);\n",
    "      }\n",
    "    }\n",
    "  }\n",
    "}\n",
    "\n",
    "AlphaMover[] make_alpha() {\n",
    "  // each mouse click, eject an alpha particle\n",
    "  AlphaMover[] alphas = {};\n",
    "  float[] center = {100.0,100.0};\n",
    "  \n",
    "  //will use 0, 1, 2\n",
    "  float[][] coords = position(center[0],center[1],8.0);\n",
    "  float[][] get_center = position(coords[0][0],coords[0][1],8.0);\n",
    "  //and this coord\n",
    "  float[][] center_coord = {{get_center[3][0],get_center[3][1]}};\n",
    "  \n",
    "  float[][] alpha_coords = {};\n",
    "  for (int k = 0; k < 3; k++) {\n",
    "    alpha_coords = (float[][])append(alpha_coords,coords[k]);\n",
    "  }\n",
    "  alpha_coords = (float[][])append(alpha_coords,center_coord[0]);\n",
    "  \n",
    "  //alpha coords is now the list of coordinates for the alpha particle\n",
    "  for (int k = 0; k < 4; k++) {\n",
    "    alphas = (AlphaMover[])append(alphas,new AlphaMover(alpha_coords[k][0],alpha_coords[k][1],2,0));\n",
    "  }\n",
    "  return alphas;\n",
    "}\n",
    "\n",
    "// create text for alpha\n",
    "float ax_loc = 50;\n",
    "float ay_loc = 135;\n",
    "float ax_vel = 0.5;\n",
    "float ay_vel = 0;\n",
    "String a_message = \"Alpha Particle\";\n",
    "int a_size = 18;\n",
    "float[] a_col = {9,49,245};\n",
    "TextBox alpha_text = new TextBox(ax_loc,ay_loc, ax_vel, ay_vel);\n",
    "\n",
    "// create the alpha particle\n",
    "AlphaMover[] alphas = make_alpha();\n",
    "\n",
    "int x = 0;\n",
    "void mousePressed() {\n",
    "  if (x == 0) {\n",
    "    x = 1;\n",
    "  } \n",
    "}\n",
    "\n",
    "void draw() {\n",
    "  background(255);\n",
    "  textSize(32);\n",
    "  fill(0);\n",
    "  text(\"Alpha Decay\", 260, 30);\n",
    "  \n",
    "  textSize(24);\n",
    "  \n",
    "  if (x == 1) {\n",
    "    for (int i = 0; i < alphas.length; i++) {\n",
    "      alphas[i].update();\n",
    "      alphas[i].display(i);\n",
    "      //draw alpha text\n",
    "      alpha_text.update();\n",
    "      alpha_text.display(a_message, a_size, a_col);\n",
    "    }\n",
    "    for (int i = 0; i < (movers.length - 4); i++) {\n",
    "      movers[i].update();\n",
    "      //movers[i].checkEdges();\n",
    "      movers[i].display(i);\n",
    "    }\n",
    "    fill(9, 49, 245);\n",
    "    text(\"Protons - 7\", 20, 170);\n",
    "    fill(96, 97, 100);\n",
    "    text(\"Neutrons - 8\", 20, 190);\n",
    "  } else {\n",
    "      for (int i = 0; i < movers.length; i++) {\n",
    "        movers[i].update();\n",
    "        //movers[i].checkEdges();\n",
    "        movers[i].display(i);\n",
    "      }\n",
    "    fill(9, 49, 245);\n",
    "    text(\"Protons - 9\", 20, 170);\n",
    "    fill(96, 97, 100);\n",
    "    text(\"Neutrons - 10\", 20, 190);\n",
    "  }\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "html_template = \"\"\"\n",
    "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
    "<script type=\"text/javascript\">\n",
    "  var processingCode = `{}`;\n",
    "  var myCanvas = document.getElementById(\"canvas2\");\n",
    "  var jsCode = Processing.compile(processingCode);\n",
    "  var processingInstance = new Processing(myCanvas, jsCode);\n",
    " </script>\n",
    "<canvas id=\"canvas2\"> </canvas>    \n",
    "\"\"\"\n",
    "\n",
    "html_code = html_template.format(utils_code+alpha_code)\n",
    "HTML(html_code)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<center> Figure 5: Alpha particles move at a relatively slow speed compared to other forms of radiation. Notice now the number of protons and neutrons in the nucleus both decrease by two.</center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Physical Properties\n",
    "\n",
    "The energy the alpha particle carries depends on the atom from which it came, with larger nuclei producing higher energy radiation. Due to the relatively large size of the alpha particle, and its positive charge, it usually does not travel very far before it interacts with some other form of matter. Therefore, we say that alpha radiation has a **low penetration**. In fact, alpha radiation can be blocked by only a few sheets of paper.\n",
    "If it is carrying a sufficient amount of energy, an alpha particle can ionize another atom upon contact. This is the inherent danger of radiation. \n",
    "\n",
    "### Biological Effects\n",
    "\n",
    "Due to its low penetration, alpha radiation has very little effect on biological matter when it originates from an external source. Most alpha particles will be stopped by thin clothing, or even dead skin cells. However, alpha radiation can become dangerous when it is contained within the body. The most common example of this is radon decay. \n",
    "The radioactive decay of heavy elements is a natural process that is constantly occuring in the Earth's crust. In the decay of uranium, a chain of elements are produced that eventually result in the formation of lead.\n",
    "\n",
    "<img src=\"http://nuclearsafety.gc.ca/images/fact-sheet-images/20120727-fs-fi-uranium-238-f1-eng.gif\" alt=\"Drawing\" style=\"width: 750px;\"/>\n",
    "<center>Image from http://nuclearsafety.gc.ca/eng/resources/fact-sheets/polonium-210.cfm</center>\n",
    "<center> Figure 6: This is the radioactive decay chain of Uranium-238, the most common isotope of uranium found in nature. As the element decays towards lead, different forms of radiation are produced. The rate at which this radiation is produced is determined by the half-life of each element. </center>\n",
    "\n",
    "During this process, a colourless, odourless gas called radon-222 is produced. Radon-222 has a relatively short half-life, meaning it is constantly decaying into polonium-218, and releasing alpha particles. When radon-222 is inhaled in high doses, the interaction between alpha particles and atoms of your body can lead to increased risk of lung cancer.\n",
    "\n",
    "\n",
    "## Beta ($\\beta$) Radiation\n",
    "\n",
    "**Beta radiation**, or **beta decay**, is another type of radioactive decay that results in the emission of a **beta particle** from the nucleus of an atom. A beta particle can be one of two things: an electron or a positron (a positively charged electron). \n",
    "Like alpha decay, beta decay is also the result of an unstable nucleus breaking down. However, unlike alpha decay, beta decay is a product of the **weak nuclear force**. \n",
    "\n",
    "The weak nuclear force acts on a subatomic level, between the quarks that compose protons and neutrons. We will not be discussing the weak nuclear force in detail here, but check out this link for more information: https://en.wikipedia.org/wiki/Weak_interaction#Interaction_types.\n",
    "\n",
    "### Creation\n",
    "There are two types of beta decay, known as $\\beta^-$ (beta minus) and $\\beta^+$ (beta plus) decay.\n",
    "\n",
    "### $\\beta^-$ Decay\n",
    "\n",
    "$\\beta^-$ decay typically occurs in a nucleus with a disproportionately high number of neutrons. In order to increase the stability of the nucleus, a neutron will change into a proton via the weak nuclear force, releasing an electron and an antineutrino in the process.\n",
    "\n",
    "Click on the nucleus below to run the animation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
       "<script type=\"text/javascript\">\n",
       "  var processingCode = `\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "\n",
       "//for beta- decay, releases electron and anti neutrino\n",
       "//large number of neutrinos, neurtino changes into a proton\n",
       "\n",
       "class BetaMinusMover extends Mover {\n",
       "  BetaMinusMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void display(int i, int rad, int col) {\n",
       "    stroke(0);\n",
       "\n",
       "    //red\n",
       "    if (col == 0) {\n",
       "      fill(255, 0, 0);\n",
       "    }\n",
       "    //green\n",
       "    else if (col == 1) {\n",
       "      fill(35, 167, 6);\n",
       "    }\n",
       "    //blue\n",
       "    else if (i % 3 ==0) {\n",
       "      fill(12, 48, 224);\n",
       "    } //grey\n",
       "    else {\n",
       "      fill(175);\n",
       "    }\n",
       "\n",
       "    ellipse(location.x, location.y, rad, rad);\n",
       "  }\n",
       "}\n",
       "\n",
       "BetaMinusMover[] movers = {};\n",
       "\n",
       "void addMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "  movers = (BetaMinusMover[])append(movers, new BetaMinusMover(x_loc, y_loc, x_vel, y_vel));\n",
       "}\n",
       "\n",
       "void setup() {\n",
       "  size(700, 200);\n",
       "  float[] center = {100.0, 100.0};\n",
       "  float[][] all_coords = {};\n",
       "  float[][] orig_coords = position(center[0], center[1], 8.0);\n",
       "  \n",
       "  //from the center, make 6 coords\n",
       "  float[][] coords = position(center[0], center[1], 8.0);\n",
       "\n",
       "  //make 6 particles\n",
       "  for (int k = 0; k < 6; k++) {\n",
       "    //if coords do not yet exist, make the circle, else, don't\n",
       "    if (!isItemInArray(all_coords, coords[k])) {\n",
       "      //create the mover\n",
       "      // add the mover to the movers list\n",
       "      addMover(coords[k][0], coords[k][1], 0, 0);\n",
       "      \n",
       "      //add coords to the list\n",
       "      all_coords = (float[][])append(all_coords, coords[k]);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  //now change the center and make new circles\n",
       "  for (int i = 0; i < 6; i++) {\n",
       "    //redefine the center \n",
       "    center[0] = orig_coords[i][0];\n",
       "    center[1] = orig_coords[i][1];\n",
       "\n",
       "    //from the center, make 6 coords\n",
       "    float[][] new_coords = position(center[0], center[1], 8.0);\n",
       "\n",
       "    //make 6 particles\n",
       "    for (int k = 0; k < 6; k++) {\n",
       "      //if coords do not yet exist, make the circle, else, don't\n",
       "      if (!isItemInArray(all_coords, new_coords[k])) {\n",
       "        //create the mover\n",
       "        // add the mover to the movers list\n",
       "        addMover(new_coords[k][0], new_coords[k][1], 0, 0);\n",
       "\n",
       "        //add coords to the list\n",
       "        all_coords = (float[][])append(all_coords, new_coords[k]);\n",
       "      }\n",
       "    }\n",
       "  }\n",
       "}\n",
       "\n",
       "BetaMinusMover[] make_betas() {\n",
       "  // each mouse click, eject an alpha particle\n",
       "  BetaMinusMover[] betas = {};\n",
       "  //electron\n",
       "  betas = (BetaMinusMover[])append(betas, new BetaMinusMover(100.0,100.0,4.0,-0.4));\n",
       "  //antineutrino\n",
       "  betas = (BetaMinusMover[])append(betas, new BetaMinusMover(100.0,100.0,4.0,0.4));\n",
       "  return betas;\n",
       "}\n",
       "\n",
       "// create the alpha particle\n",
       "BetaMinusMover[] betas = make_betas();\n",
       "int x = 0;\n",
       "\n",
       "// create text for electron\n",
       "float ex_loc = 50;\n",
       "float ey_loc = 120;\n",
       "float ex_vel = 4;\n",
       "float ey_vel = -0.4;\n",
       "String e_message = \"Electron\";\n",
       "int e_size = 18;\n",
       "float[] e_col = {255,0,0};\n",
       "TextBox elec_text = new TextBox(ex_loc,ey_loc, ex_vel, ey_vel);\n",
       "\n",
       "// create text for antineutrino\n",
       "float ax_loc = 50;\n",
       "float ay_loc = 120;\n",
       "float ax_vel = 4;\n",
       "float ay_vel = 0.4;\n",
       "String a_message = \"Antineutrino\";\n",
       "int a_size = 18;\n",
       "float[] a_col = {35, 167, 6};\n",
       "TextBox anti_text = new TextBox(ax_loc,ay_loc, ax_vel, ay_vel);\n",
       "\n",
       "void mousePressed() {\n",
       "  if (x == 0) {\n",
       "    x = 1;\n",
       "  } \n",
       "}\n",
       "\n",
       "void draw() {\n",
       "  background(255);\n",
       "  textSize(32);\n",
       "  fill(0);\n",
       "  text(\"Beta Minus Decay\", 220, 30);\n",
       "  \n",
       "  textSize(24);\n",
       "  \n",
       "  if (x == 1) {\n",
       "    for (int i = 0; i < betas.length; i++) {\n",
       "      betas[i].update();\n",
       "      betas[i].display(i,8,i);\n",
       "    }\n",
       "    //draw electron text\n",
       "    elec_text.update();\n",
       "    elec_text.display(e_message, e_size, e_col);\n",
       "    //draw anti neutrino text\n",
       "    anti_text.update();\n",
       "    anti_text.display(a_message,a_size,a_col);\n",
       "    \n",
       "    for (int i = 0; i < (movers.length) - 2; i++) {\n",
       "      movers[i].update();\n",
       "      movers[i].display(i,16,2);\n",
       "    }\n",
       "    //add a proton\n",
       "    movers[17].display(3,16,2);\n",
       "    movers[18].display(3,16,2);\n",
       "    fill(9, 49, 245);\n",
       "    text(\"Protons - 8\", 20, 170);\n",
       "    fill(96, 97, 100);\n",
       "    text(\"Neutrons - 11\", 20, 190);\n",
       "  } else {\n",
       "      for (int i = 0; i < movers.length; i++) {\n",
       "        movers[i].update();\n",
       "        //movers[i].checkEdges();\n",
       "        movers[i].display(i,16,2);\n",
       "      }\n",
       "    fill(9, 49, 245);\n",
       "    text(\"Protons - 7\", 20, 170);\n",
       "    fill(96, 97, 100);\n",
       "    text(\"Neutrons - 12\", 20, 190);\n",
       "  }\n",
       "}\n",
       "`;\n",
       "  var myCanvas = document.getElementById(\"canvas3\");\n",
       "  var jsCode = Processing.compile(processingCode);\n",
       "  var processingInstance = new Processing(myCanvas, jsCode);\n",
       " </script>\n",
       "<canvas id=\"canvas3\"> </canvas>    \n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "beta_minus_code = \"\"\"\n",
    "//for beta- decay, releases electron and anti neutrino\n",
    "//large number of neutrinos, neurtino changes into a proton\n",
    "\n",
    "class BetaMinusMover extends Mover {\n",
    "  BetaMinusMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  void display(int i, int rad, int col) {\n",
    "    stroke(0);\n",
    "\n",
    "    //red\n",
    "    if (col == 0) {\n",
    "      fill(255, 0, 0);\n",
    "    }\n",
    "    //green\n",
    "    else if (col == 1) {\n",
    "      fill(35, 167, 6);\n",
    "    }\n",
    "    //blue\n",
    "    else if (i % 3 ==0) {\n",
    "      fill(12, 48, 224);\n",
    "    } //grey\n",
    "    else {\n",
    "      fill(175);\n",
    "    }\n",
    "\n",
    "    ellipse(location.x, location.y, rad, rad);\n",
    "  }\n",
    "}\n",
    "\n",
    "BetaMinusMover[] movers = {};\n",
    "\n",
    "void addMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "  movers = (BetaMinusMover[])append(movers, new BetaMinusMover(x_loc, y_loc, x_vel, y_vel));\n",
    "}\n",
    "\n",
    "void setup() {\n",
    "  size(700, 200);\n",
    "  float[] center = {100.0, 100.0};\n",
    "  float[][] all_coords = {};\n",
    "  float[][] orig_coords = position(center[0], center[1], 8.0);\n",
    "  \n",
    "  //from the center, make 6 coords\n",
    "  float[][] coords = position(center[0], center[1], 8.0);\n",
    "\n",
    "  //make 6 particles\n",
    "  for (int k = 0; k < 6; k++) {\n",
    "    //if coords do not yet exist, make the circle, else, don't\n",
    "    if (!isItemInArray(all_coords, coords[k])) {\n",
    "      //create the mover\n",
    "      // add the mover to the movers list\n",
    "      addMover(coords[k][0], coords[k][1], 0, 0);\n",
    "      \n",
    "      //add coords to the list\n",
    "      all_coords = (float[][])append(all_coords, coords[k]);\n",
    "    }\n",
    "  }\n",
    "\n",
    "  //now change the center and make new circles\n",
    "  for (int i = 0; i < 6; i++) {\n",
    "    //redefine the center \n",
    "    center[0] = orig_coords[i][0];\n",
    "    center[1] = orig_coords[i][1];\n",
    "\n",
    "    //from the center, make 6 coords\n",
    "    float[][] new_coords = position(center[0], center[1], 8.0);\n",
    "\n",
    "    //make 6 particles\n",
    "    for (int k = 0; k < 6; k++) {\n",
    "      //if coords do not yet exist, make the circle, else, don't\n",
    "      if (!isItemInArray(all_coords, new_coords[k])) {\n",
    "        //create the mover\n",
    "        // add the mover to the movers list\n",
    "        addMover(new_coords[k][0], new_coords[k][1], 0, 0);\n",
    "\n",
    "        //add coords to the list\n",
    "        all_coords = (float[][])append(all_coords, new_coords[k]);\n",
    "      }\n",
    "    }\n",
    "  }\n",
    "}\n",
    "\n",
    "BetaMinusMover[] make_betas() {\n",
    "  // each mouse click, eject an alpha particle\n",
    "  BetaMinusMover[] betas = {};\n",
    "  //electron\n",
    "  betas = (BetaMinusMover[])append(betas, new BetaMinusMover(100.0,100.0,4.0,-0.4));\n",
    "  //antineutrino\n",
    "  betas = (BetaMinusMover[])append(betas, new BetaMinusMover(100.0,100.0,4.0,0.4));\n",
    "  return betas;\n",
    "}\n",
    "\n",
    "// create the alpha particle\n",
    "BetaMinusMover[] betas = make_betas();\n",
    "int x = 0;\n",
    "\n",
    "// create text for electron\n",
    "float ex_loc = 50;\n",
    "float ey_loc = 120;\n",
    "float ex_vel = 4;\n",
    "float ey_vel = -0.4;\n",
    "String e_message = \"Electron\";\n",
    "int e_size = 18;\n",
    "float[] e_col = {255,0,0};\n",
    "TextBox elec_text = new TextBox(ex_loc,ey_loc, ex_vel, ey_vel);\n",
    "\n",
    "// create text for antineutrino\n",
    "float ax_loc = 50;\n",
    "float ay_loc = 120;\n",
    "float ax_vel = 4;\n",
    "float ay_vel = 0.4;\n",
    "String a_message = \"Antineutrino\";\n",
    "int a_size = 18;\n",
    "float[] a_col = {35, 167, 6};\n",
    "TextBox anti_text = new TextBox(ax_loc,ay_loc, ax_vel, ay_vel);\n",
    "\n",
    "void mousePressed() {\n",
    "  if (x == 0) {\n",
    "    x = 1;\n",
    "  } \n",
    "}\n",
    "\n",
    "void draw() {\n",
    "  background(255);\n",
    "  textSize(32);\n",
    "  fill(0);\n",
    "  text(\"Beta Minus Decay\", 220, 30);\n",
    "  \n",
    "  textSize(24);\n",
    "  \n",
    "  if (x == 1) {\n",
    "    for (int i = 0; i < betas.length; i++) {\n",
    "      betas[i].update();\n",
    "      betas[i].display(i,8,i);\n",
    "    }\n",
    "    //draw electron text\n",
    "    elec_text.update();\n",
    "    elec_text.display(e_message, e_size, e_col);\n",
    "    //draw anti neutrino text\n",
    "    anti_text.update();\n",
    "    anti_text.display(a_message,a_size,a_col);\n",
    "    \n",
    "    for (int i = 0; i < (movers.length) - 2; i++) {\n",
    "      movers[i].update();\n",
    "      movers[i].display(i,16,2);\n",
    "    }\n",
    "    //add a proton\n",
    "    movers[17].display(3,16,2);\n",
    "    movers[18].display(3,16,2);\n",
    "    fill(9, 49, 245);\n",
    "    text(\"Protons - 8\", 20, 170);\n",
    "    fill(96, 97, 100);\n",
    "    text(\"Neutrons - 11\", 20, 190);\n",
    "  } else {\n",
    "      for (int i = 0; i < movers.length; i++) {\n",
    "        movers[i].update();\n",
    "        //movers[i].checkEdges();\n",
    "        movers[i].display(i,16,2);\n",
    "      }\n",
    "    fill(9, 49, 245);\n",
    "    text(\"Protons - 7\", 20, 170);\n",
    "    fill(96, 97, 100);\n",
    "    text(\"Neutrons - 12\", 20, 190);\n",
    "  }\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "html_template = \"\"\"\n",
    "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
    "<script type=\"text/javascript\">\n",
    "  var processingCode = `{}`;\n",
    "  var myCanvas = document.getElementById(\"canvas3\");\n",
    "  var jsCode = Processing.compile(processingCode);\n",
    "  var processingInstance = new Processing(myCanvas, jsCode);\n",
    " </script>\n",
    "<canvas id=\"canvas3\"> </canvas>    \n",
    "\"\"\"\n",
    "\n",
    "html_code = html_template.format(utils_code+beta_minus_code)\n",
    "HTML(html_code)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<center> Figure 7: $\\beta^-$ decay involves a neutron changing into a proton. Notice how the electron and antineutrino travel faster than the alpha particle in the previous animation.</center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### $\\beta^+$ Decay\n",
    "\n",
    "$\\beta^+$ decay will occur in a nucleus with a high number of protons. In contrast to $\\beta^-$ decay, a proton will change into a neutron, releasing a positron and a neutrino.\n",
    "\n",
    "Click on the nucleus below to run the animation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
       "<script type=\"text/javascript\">\n",
       "  var processingCode = `\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "\n",
       "//for beta+ decay, releases positrion and neutrino\n",
       "//large number of protons, proton changes into a neutrino\n",
       "\n",
       "class BetaPlusMover extends Mover {\n",
       "  BetaPlusMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void display(int i, int rad, int col) {\n",
       "    stroke(0);\n",
       "\n",
       "    //purple positron\n",
       "    if (col == 0) {\n",
       "      fill(154, 5, 198);\n",
       "    }\n",
       "    //orange neutrino\n",
       "    else if (col == 1) {\n",
       "      fill(255, 111, 6);\n",
       "    }\n",
       "    //grey neutrons\n",
       "    else if (i % 3 == 0) {\n",
       "      fill(175);\n",
       "    }\n",
       "    //blue protons\n",
       "    else {\n",
       "      fill(12, 48, 224);\n",
       "    }\n",
       "\n",
       "    ellipse(location.x, location.y, rad, rad);\n",
       "  }\n",
       "}\n",
       "\n",
       "BetaPlusMover[] movers = {};\n",
       "\n",
       "void addMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "  movers = (BetasPlusMover[])append(movers, new BetaPlusMover(x_loc, y_loc, x_vel, y_vel));\n",
       "}\n",
       "\n",
       "void setup() {\n",
       "  size(700, 200);\n",
       "  float[] center = {100.0, 100.0};\n",
       "  float[][] all_coords = {};\n",
       "  float[][] orig_coords = position(center[0], center[1], 8.0);\n",
       "  \n",
       "  //from the center, make 6 coords\n",
       "  float[][] coords = position(center[0], center[1], 8.0);\n",
       "\n",
       "  //make 6 particles\n",
       "  for (int k = 0; k < 6; k++) {\n",
       "    //if coords do not yet exist, make the circle, else, don't\n",
       "    if (!isItemInArray(all_coords, coords[k])) {\n",
       "      //create the mover\n",
       "      // add the mover to the movers list\n",
       "      addMover(coords[k][0], coords[k][1], 0, 0);\n",
       "      \n",
       "      //add coords to the list\n",
       "      all_coords = (float[][])append(all_coords, coords[k]);\n",
       "    }\n",
       "  }\n",
       "\n",
       "  //now change the center and make new circles\n",
       "  for (int i = 0; i < 6; i++) {\n",
       "    //redefine the center \n",
       "    center[0] = orig_coords[i][0];\n",
       "    center[1] = orig_coords[i][1];\n",
       "\n",
       "    //from the center, make 6 coords\n",
       "    float[][] new_coords = position(center[0], center[1], 8.0);\n",
       "\n",
       "    //make 6 particles\n",
       "    for (int k = 0; k < 6; k++) {\n",
       "      //if coords do not yet exist, make the circle, else, don't\n",
       "      if (!isItemInArray(all_coords, new_coords[k])) {\n",
       "        //create the mover\n",
       "        // add the mover to the movers list\n",
       "        addMover(new_coords[k][0], new_coords[k][1], 0, 0);\n",
       "\n",
       "        //add coords to the list\n",
       "        all_coords = (float[][])append(all_coords, new_coords[k]);\n",
       "      }\n",
       "    }\n",
       "  }\n",
       "}\n",
       "\n",
       "BetaPlusMover[] make_betas() {\n",
       "  // each mouse click, eject an alpha particle\n",
       "  BetaPlusMover[] betas = {};\n",
       "  \n",
       "  betas = (BetaPlusMover[])append(betas,new BetaPlusMover(100.0,100.0,4.0,-0.4));\n",
       "  betas = (BetaPlusMover[])append(betas,new BetaPlusMover(100.0,100.0,4.0,0.4));\n",
       "  return betas;\n",
       "}\n",
       "\n",
       "// create the alpha particle\n",
       "BetaPlusMover[] betas = make_betas();\n",
       "int x = 0;\n",
       "\n",
       "// create text for positron\n",
       "float px_loc = 50;\n",
       "float py_loc = 120;\n",
       "float px_vel = 4;\n",
       "float py_vel = -0.4;\n",
       "String p_message = \"Positron\";\n",
       "int p_size = 18;\n",
       "float[] p_col = {154, 5, 198};\n",
       "TextBox posi_text = new TextBox(px_loc,py_loc, px_vel, py_vel);\n",
       "\n",
       "// create text for neutrino\n",
       "float nx_loc = 50;\n",
       "float ny_loc = 120;\n",
       "float nx_vel = 4;\n",
       "float ny_vel = 0.4;\n",
       "String n_message = \"Neutrino\";\n",
       "int n_size = 18;\n",
       "float[] n_col = {255, 111, 6};\n",
       "TextBox neut_text = new TextBox(nx_loc,ny_loc, nx_vel, ny_vel);\n",
       "\n",
       "void mousePressed() {\n",
       "  if (x == 0) {\n",
       "    x = 1;\n",
       "  } \n",
       "}\n",
       "\n",
       "void draw() {\n",
       "  background(255);\n",
       "  //title\n",
       "  textSize(32);\n",
       "  fill(0);\n",
       "  text(\"Beta Plus Decay\", 235, 30);\n",
       "  \n",
       "  textSize(24);\n",
       "  \n",
       "  if (x == 1) {\n",
       "    for (int i = 0; i < betas.length; i++) {\n",
       "      betas[i].update();\n",
       "      betas[i].display(i,8,i);\n",
       "    }\n",
       "    \n",
       "    //draw positron text\n",
       "    posi_text.update();\n",
       "    posi_text.display(p_message, p_size, p_col);\n",
       "    //draw neutrino text\n",
       "    neut_text.update();\n",
       "    neut_text.display(n_message,n_size,n_col);\n",
       "    \n",
       "    for (int i = 0; i < (movers.length) - 2; i++) {\n",
       "      movers[i].update();\n",
       "      movers[i].display(i,16,2);\n",
       "    }\n",
       "    //add a neutron\n",
       "    movers[17].display(3,16,2);\n",
       "    movers[18].display(3,16,2);\n",
       "    fill(9, 49, 245);\n",
       "    text(\"Protons - 11\", 20, 170);\n",
       "    fill(96, 97, 100);\n",
       "    text(\"Neutrons - 8\", 20, 190);\n",
       "  } else {\n",
       "      for (int i = 0; i < movers.length; i++) {\n",
       "        movers[i].update();\n",
       "        //movers[i].checkEdges();\n",
       "        movers[i].display(i,16,2);\n",
       "      }\n",
       "    fill(9, 49, 245);\n",
       "    text(\"Protons - 12\", 20, 170);\n",
       "    fill(96, 97, 100);\n",
       "    text(\"Neutrons - 7\", 20, 190);\n",
       "  }\n",
       "}\n",
       "`;\n",
       "  var myCanvas = document.getElementById(\"canvas4\");\n",
       "  var jsCode = Processing.compile(processingCode);\n",
       "  var processingInstance = new Processing(myCanvas, jsCode);\n",
       " </script>\n",
       "<canvas id=\"canvas4\"> </canvas>    \n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "beta_plus_code = \"\"\"\n",
    "//for beta+ decay, releases positrion and neutrino\n",
    "//large number of protons, proton changes into a neutrino\n",
    "\n",
    "class BetaPlusMover extends Mover {\n",
    "  BetaPlusMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  void display(int i, int rad, int col) {\n",
    "    stroke(0);\n",
    "\n",
    "    //purple positron\n",
    "    if (col == 0) {\n",
    "      fill(154, 5, 198);\n",
    "    }\n",
    "    //orange neutrino\n",
    "    else if (col == 1) {\n",
    "      fill(255, 111, 6);\n",
    "    }\n",
    "    //grey neutrons\n",
    "    else if (i % 3 == 0) {\n",
    "      fill(175);\n",
    "    }\n",
    "    //blue protons\n",
    "    else {\n",
    "      fill(12, 48, 224);\n",
    "    }\n",
    "\n",
    "    ellipse(location.x, location.y, rad, rad);\n",
    "  }\n",
    "}\n",
    "\n",
    "BetaPlusMover[] movers = {};\n",
    "\n",
    "void addMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "  movers = (BetasPlusMover[])append(movers, new BetaPlusMover(x_loc, y_loc, x_vel, y_vel));\n",
    "}\n",
    "\n",
    "void setup() {\n",
    "  size(700, 200);\n",
    "  float[] center = {100.0, 100.0};\n",
    "  float[][] all_coords = {};\n",
    "  float[][] orig_coords = position(center[0], center[1], 8.0);\n",
    "  \n",
    "  //from the center, make 6 coords\n",
    "  float[][] coords = position(center[0], center[1], 8.0);\n",
    "\n",
    "  //make 6 particles\n",
    "  for (int k = 0; k < 6; k++) {\n",
    "    //if coords do not yet exist, make the circle, else, don't\n",
    "    if (!isItemInArray(all_coords, coords[k])) {\n",
    "      //create the mover\n",
    "      // add the mover to the movers list\n",
    "      addMover(coords[k][0], coords[k][1], 0, 0);\n",
    "      \n",
    "      //add coords to the list\n",
    "      all_coords = (float[][])append(all_coords, coords[k]);\n",
    "    }\n",
    "  }\n",
    "\n",
    "  //now change the center and make new circles\n",
    "  for (int i = 0; i < 6; i++) {\n",
    "    //redefine the center \n",
    "    center[0] = orig_coords[i][0];\n",
    "    center[1] = orig_coords[i][1];\n",
    "\n",
    "    //from the center, make 6 coords\n",
    "    float[][] new_coords = position(center[0], center[1], 8.0);\n",
    "\n",
    "    //make 6 particles\n",
    "    for (int k = 0; k < 6; k++) {\n",
    "      //if coords do not yet exist, make the circle, else, don't\n",
    "      if (!isItemInArray(all_coords, new_coords[k])) {\n",
    "        //create the mover\n",
    "        // add the mover to the movers list\n",
    "        addMover(new_coords[k][0], new_coords[k][1], 0, 0);\n",
    "\n",
    "        //add coords to the list\n",
    "        all_coords = (float[][])append(all_coords, new_coords[k]);\n",
    "      }\n",
    "    }\n",
    "  }\n",
    "}\n",
    "\n",
    "BetaPlusMover[] make_betas() {\n",
    "  // each mouse click, eject an alpha particle\n",
    "  BetaPlusMover[] betas = {};\n",
    "  \n",
    "  betas = (BetaPlusMover[])append(betas,new BetaPlusMover(100.0,100.0,4.0,-0.4));\n",
    "  betas = (BetaPlusMover[])append(betas,new BetaPlusMover(100.0,100.0,4.0,0.4));\n",
    "  return betas;\n",
    "}\n",
    "\n",
    "// create the alpha particle\n",
    "BetaPlusMover[] betas = make_betas();\n",
    "int x = 0;\n",
    "\n",
    "// create text for positron\n",
    "float px_loc = 50;\n",
    "float py_loc = 120;\n",
    "float px_vel = 4;\n",
    "float py_vel = -0.4;\n",
    "String p_message = \"Positron\";\n",
    "int p_size = 18;\n",
    "float[] p_col = {154, 5, 198};\n",
    "TextBox posi_text = new TextBox(px_loc,py_loc, px_vel, py_vel);\n",
    "\n",
    "// create text for neutrino\n",
    "float nx_loc = 50;\n",
    "float ny_loc = 120;\n",
    "float nx_vel = 4;\n",
    "float ny_vel = 0.4;\n",
    "String n_message = \"Neutrino\";\n",
    "int n_size = 18;\n",
    "float[] n_col = {255, 111, 6};\n",
    "TextBox neut_text = new TextBox(nx_loc,ny_loc, nx_vel, ny_vel);\n",
    "\n",
    "void mousePressed() {\n",
    "  if (x == 0) {\n",
    "    x = 1;\n",
    "  } \n",
    "}\n",
    "\n",
    "void draw() {\n",
    "  background(255);\n",
    "  //title\n",
    "  textSize(32);\n",
    "  fill(0);\n",
    "  text(\"Beta Plus Decay\", 235, 30);\n",
    "  \n",
    "  textSize(24);\n",
    "  \n",
    "  if (x == 1) {\n",
    "    for (int i = 0; i < betas.length; i++) {\n",
    "      betas[i].update();\n",
    "      betas[i].display(i,8,i);\n",
    "    }\n",
    "    \n",
    "    //draw positron text\n",
    "    posi_text.update();\n",
    "    posi_text.display(p_message, p_size, p_col);\n",
    "    //draw neutrino text\n",
    "    neut_text.update();\n",
    "    neut_text.display(n_message,n_size,n_col);\n",
    "    \n",
    "    for (int i = 0; i < (movers.length) - 2; i++) {\n",
    "      movers[i].update();\n",
    "      movers[i].display(i,16,2);\n",
    "    }\n",
    "    //add a neutron\n",
    "    movers[17].display(3,16,2);\n",
    "    movers[18].display(3,16,2);\n",
    "    fill(9, 49, 245);\n",
    "    text(\"Protons - 11\", 20, 170);\n",
    "    fill(96, 97, 100);\n",
    "    text(\"Neutrons - 8\", 20, 190);\n",
    "  } else {\n",
    "      for (int i = 0; i < movers.length; i++) {\n",
    "        movers[i].update();\n",
    "        //movers[i].checkEdges();\n",
    "        movers[i].display(i,16,2);\n",
    "      }\n",
    "    fill(9, 49, 245);\n",
    "    text(\"Protons - 12\", 20, 170);\n",
    "    fill(96, 97, 100);\n",
    "    text(\"Neutrons - 7\", 20, 190);\n",
    "  }\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "html_template = \"\"\"\n",
    "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
    "<script type=\"text/javascript\">\n",
    "  var processingCode = `{}`;\n",
    "  var myCanvas = document.getElementById(\"canvas4\");\n",
    "  var jsCode = Processing.compile(processingCode);\n",
    "  var processingInstance = new Processing(myCanvas, jsCode);\n",
    " </script>\n",
    "<canvas id=\"canvas4\"> </canvas>    \n",
    "\"\"\"\n",
    "\n",
    "html_code = html_template.format(utils_code+beta_plus_code)\n",
    "HTML(html_code)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Figure 8: $\\beta^+$ decay involves a proton changing into a neutron. The ejected particles travel at the same speed as those in $\\beta^-$ decay."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Physical Properties\n",
    "\n",
    "A beta particle is significantly less massive than an alpha particle, and only carries 1 unit of charge. To compare, the mass of a beta particle is approximately 1/8000 the mass of an alpha particle. Their low mass enables them to travel at ultrarelativistic speeds (speeds nearing the speed of light). With a small size and low charge, they are able to travel longer distances before interacting with matter, lending them a higher penetrating power than alpha particles. Beta particles are able to travel into soft tissue from external sources, although they will be blocked by material such as plastic or aluminum.\n",
    "\n",
    "### Biological Effects\n",
    "\n",
    "Like alpha particles, beta radiation has the potential to ionize the atoms they contact. Due to its penetrative power, beta radiation can cause external burns, tissue damage, and acute radiation poisoning. Some of the most common beta emitters are carbon-14, and yttrium-90. \n",
    "\n",
    "You may be familiar with the process known as radiocarbon dating: the method through which we can determine the age of organic matter. Radiocarbon dating measures the amount of carbon-14 in a dead organic sample, and compares this amount to the expected amount present while the sample was still alive. Carbon-14 is constantly decaying and emitting beta particles at a rate governed by it's half-life of 5,730 years, so the difference between the original amount present in a living sample and the measured amount tells us exactly how long it has been since the sample died."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<img src=\"http://1.bp.blogspot.com/-q1KfOPVR0r8/VgHUXZrQ4bI/AAAAAAAACCc/O8N0eel3MsY/s1600/c14_3.jpg\" alt=\"Drawing\" style=\"width: 500px;\"/>\n",
    "<center>Image from http://geologylearn.blogspot.com/2015/09/carbon-dating.html</center>\n",
    "<center> Figure 9: Radiocarbon dating is the method that allows us to determine the age of fossils. </center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Yttrium-90 is another example of a useful beta emitter. Yttrium-90 is used to treat cancer patients via radiation therapy. This procedure involves bombarding acute areas of cancerous tumors with beta radiation, in hopes that the destructive nature of the radiation will eradicate the tumor. The side effects of this therapy are congruent with the symptoms of radiation poisoning, but it is often effective in improving the patients quality of life. \n",
    "\n",
    "## Gamma ($\\gamma$) Radiation\n",
    "\n",
    "**Gamma radiation** differs from both alpha and beta radiation in that it does not take the form of a particle, but is rather a type of high energy EMR. There are a few different processes that can produce gamma rays, but each requires an event that releases a large amount of energy.\n",
    "\n",
    "### Creation\n",
    "\n",
    "#### Particle Collisions\n",
    "\n",
    "When two particles carrying sufficient energy collide, they may create a gamma ray. The conditions creating such a collision are quite rare in the universe, and can only be created on Earth within particle accelerators or nuclear reactors.\n",
    "Out in the universe, there are objects that are capable of producing gamma rays due to the extreme nature of their conditions. Black holes, neutron stars, supernova and quasars are a few examples of objects that regularly emit gamma radiation. The unique conditions required to produce gamma radiation enable us to gather information on these objects by analyzing the radiation they send to us.\n",
    "\n",
    "#### Annihilation Reactions\n",
    "\n",
    "When a particle collides with its antiparticle, an **annihilation** reaction can occur. For example, if an electron collides with a positron, they transform into pure energy in the form  gamma rays.\n",
    "\n",
    "Click on the animation below to create an annihilation reaction."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
       "<script type=\"text/javascript\">\n",
       "  var processingCode = `\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "\n",
       "//annihilation reaction\n",
       "\n",
       "//for beta- decay, releases electron and anti neutrino\n",
       "//large number of neutrinos, neurtino changes into a proton\n",
       "\n",
       "class AnnihilationMover extends Mover {\n",
       "  AnnihilationMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void display(int rad, int col) {\n",
       "    stroke(0);\n",
       "\n",
       "    //purple positron\n",
       "    if (col == 0) {\n",
       "      fill(154, 5, 198);\n",
       "    }\n",
       "    //red electron\n",
       "    else if (col == 1) {\n",
       "      fill(255, 0, 0);\n",
       "    }\n",
       "\n",
       "    ellipse(location.x, location.y, rad, rad);\n",
       "  }\n",
       "}\n",
       "\n",
       "boolean check_collision(AnnihilationMover one, AnnihilationMover two) {\n",
       "  //take the coordinates of each particle and check if they are the same\n",
       "  \n",
       "  if(one.location.x == two.location.x && one.location.y == two.location.y) {\n",
       "    return true;\n",
       "  } else {\n",
       "    return false;\n",
       "  }\n",
       "}\n",
       "\n",
       "//create two movers, a positron and an electron\n",
       "//have them move to the same position\n",
       "//from that position, eject two gamma rays\n",
       "\n",
       "void setup() {\n",
       "  size(700,200);\n",
       "}\n",
       "\n",
       "//make two movers\n",
       "// create positron and electron\n",
       "AnnihilationMover positron = new AnnihilationMover(50,50,2.0,0.25);\n",
       "AnnihilationMover electron = new AnnihilationMover(50,150,2.0,-0.25);\n",
       "\n",
       "//create gamma rays\n",
       "Gamma g_up = new Gamma(435,100,2.0,-0.75);\n",
       "Gamma g_down = new Gamma(435,100,2.0,0.75);\n",
       "\n",
       "// create text for electron\n",
       "float ex_loc = 25;\n",
       "float ey_loc = 170;\n",
       "float ex_vel = 2;\n",
       "float ey_vel = -0.25;\n",
       "String e_message = \"Electron\";\n",
       "int e_size = 12;\n",
       "float[] e_col = {255,0,0};\n",
       "TextBox elec_text = new TextBox(ex_loc,ey_loc, ex_vel, ey_vel);\n",
       "\n",
       "// create text for positron\n",
       "float px_loc = 25;\n",
       "float py_loc = 40;\n",
       "float px_vel = 2;\n",
       "float py_vel = 0.25;\n",
       "String p_message = \"Positron\";\n",
       "int p_size = 12;\n",
       "float[] p_col = {154, 5, 198};\n",
       "TextBox posi_text = new TextBox(px_loc,py_loc, px_vel, py_vel);\n",
       "\n",
       "int x = 0;\n",
       "void mousePressed() {\n",
       "  if (x == 0) {\n",
       "    x = 1;\n",
       "  } \n",
       "}\n",
       "\n",
       "void draw() {\n",
       "  background(255);\n",
       "  textSize(20);\n",
       "  fill(0);\n",
       "  text(\"Annihilation Reaction\", 250, 25);\n",
       "  \n",
       "  textSize(24);\n",
       "  \n",
       "  if (x == 0) {\n",
       "    electron.display(8,1);\n",
       "    positron.display(8,0);\n",
       "    elec_text.display(e_message,e_size,e_col);\n",
       "    posi_text.display(p_message,p_size,p_col);\n",
       "  } else {\n",
       "    if (check_collision(electron, positron) == true) {\n",
       "      //draw two gamma rays\n",
       "      //up\n",
       "      g_up.update();\n",
       "      g_up.display(1,330);\n",
       "    \n",
       "      ////down\n",
       "      g_down.update();\n",
       "      g_down.display(0,20);\n",
       "    } else {\n",
       "      posi_text.update();\n",
       "      posi_text.display(p_message,p_size,p_col);\n",
       "      positron.update();\n",
       "      positron.display(8,0);\n",
       "    \n",
       "      elec_text.update();\n",
       "      elec_text.display(e_message,e_size,e_col);\n",
       "      electron.update();\n",
       "      electron.display(8,1);\n",
       "    }\n",
       "  }\n",
       "}\n",
       "`;\n",
       "  var myCanvas = document.getElementById(\"canvas5\");\n",
       "  var jsCode = Processing.compile(processingCode);\n",
       "  var processingInstance = new Processing(myCanvas, jsCode);\n",
       " </script>\n",
       "<canvas id=\"canvas5\"> </canvas>    \n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "annihilation_code = \"\"\"\n",
    "//annihilation reaction\n",
    "\n",
    "//for beta- decay, releases electron and anti neutrino\n",
    "//large number of neutrinos, neurtino changes into a proton\n",
    "\n",
    "class AnnihilationMover extends Mover {\n",
    "  AnnihilationMover(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "  }\n",
    "\n",
    "  void display(int rad, int col) {\n",
    "    stroke(0);\n",
    "\n",
    "    //purple positron\n",
    "    if (col == 0) {\n",
    "      fill(154, 5, 198);\n",
    "    }\n",
    "    //red electron\n",
    "    else if (col == 1) {\n",
    "      fill(255, 0, 0);\n",
    "    }\n",
    "\n",
    "    ellipse(location.x, location.y, rad, rad);\n",
    "  }\n",
    "}\n",
    "\n",
    "boolean check_collision(AnnihilationMover one, AnnihilationMover two) {\n",
    "  //take the coordinates of each particle and check if they are the same\n",
    "  \n",
    "  if(one.location.x == two.location.x && one.location.y == two.location.y) {\n",
    "    return true;\n",
    "  } else {\n",
    "    return false;\n",
    "  }\n",
    "}\n",
    "\n",
    "//create two movers, a positron and an electron\n",
    "//have them move to the same position\n",
    "//from that position, eject two gamma rays\n",
    "\n",
    "void setup() {\n",
    "  size(700,200);\n",
    "}\n",
    "\n",
    "//make two movers\n",
    "// create positron and electron\n",
    "AnnihilationMover positron = new AnnihilationMover(50,50,2.0,0.25);\n",
    "AnnihilationMover electron = new AnnihilationMover(50,150,2.0,-0.25);\n",
    "\n",
    "//create gamma rays\n",
    "Gamma g_up = new Gamma(435,100,2.0,-0.75);\n",
    "Gamma g_down = new Gamma(435,100,2.0,0.75);\n",
    "\n",
    "// create text for electron\n",
    "float ex_loc = 25;\n",
    "float ey_loc = 170;\n",
    "float ex_vel = 2;\n",
    "float ey_vel = -0.25;\n",
    "String e_message = \"Electron\";\n",
    "int e_size = 12;\n",
    "float[] e_col = {255,0,0};\n",
    "TextBox elec_text = new TextBox(ex_loc,ey_loc, ex_vel, ey_vel);\n",
    "\n",
    "// create text for positron\n",
    "float px_loc = 25;\n",
    "float py_loc = 40;\n",
    "float px_vel = 2;\n",
    "float py_vel = 0.25;\n",
    "String p_message = \"Positron\";\n",
    "int p_size = 12;\n",
    "float[] p_col = {154, 5, 198};\n",
    "TextBox posi_text = new TextBox(px_loc,py_loc, px_vel, py_vel);\n",
    "\n",
    "int x = 0;\n",
    "void mousePressed() {\n",
    "  if (x == 0) {\n",
    "    x = 1;\n",
    "  } \n",
    "}\n",
    "\n",
    "void draw() {\n",
    "  background(255);\n",
    "  textSize(20);\n",
    "  fill(0);\n",
    "  text(\"Annihilation Reaction\", 250, 25);\n",
    "  \n",
    "  textSize(24);\n",
    "  \n",
    "  if (x == 0) {\n",
    "    electron.display(8,1);\n",
    "    positron.display(8,0);\n",
    "    elec_text.display(e_message,e_size,e_col);\n",
    "    posi_text.display(p_message,p_size,p_col);\n",
    "  } else {\n",
    "    if (check_collision(electron, positron) == true) {\n",
    "      //draw two gamma rays\n",
    "      //up\n",
    "      g_up.update();\n",
    "      g_up.display(1,330);\n",
    "    \n",
    "      ////down\n",
    "      g_down.update();\n",
    "      g_down.display(0,20);\n",
    "    } else {\n",
    "      posi_text.update();\n",
    "      posi_text.display(p_message,p_size,p_col);\n",
    "      positron.update();\n",
    "      positron.display(8,0);\n",
    "    \n",
    "      elec_text.update();\n",
    "      elec_text.display(e_message,e_size,e_col);\n",
    "      electron.update();\n",
    "      electron.display(8,1);\n",
    "    }\n",
    "  }\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "html_template = \"\"\"\n",
    "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
    "<script type=\"text/javascript\">\n",
    "  var processingCode = `{}`;\n",
    "  var myCanvas = document.getElementById(\"canvas5\");\n",
    "  var jsCode = Processing.compile(processingCode);\n",
    "  var processingInstance = new Processing(myCanvas, jsCode);\n",
    " </script>\n",
    "<canvas id=\"canvas5\"> </canvas>    \n",
    "\"\"\"\n",
    "\n",
    "html_code = html_template.format(utils_code+annihilation_code)\n",
    "HTML(html_code)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<center> Figure 10: An annihilation reaction. Upon collision, the particles are destroyed and create gamma rays in the process.</center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Antimatter is not typically found on Earth under natural circumstances. It is often the byproduct of different nuclear reactions or particle collisions, and will not survive very long before undergoing an annihilation reaction.\n",
    "\n",
    "\n",
    "#### Particle Acceleration\n",
    "\n",
    "When a fast moving charged particle decelerates rapidly, this change in energy can be released in the form of a gamma ray. This phenomenon is also known as **bremsstrahlung** radiation. Bremsstrahlung will occur when a charged particle passes through an external electric or magnetic field at high velocity. The pull of the external field causes the particle to decelerate rapidly, and the kinetic energy that is lost is converted into radiation. When this energy difference is large enough, gamma rays may be emitted.\n",
    "\n",
    "Click on the animation below to demonstrate bremsstrahlung radiation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
       "<script type=\"text/javascript\">\n",
       "  var processingCode = `\n",
       "class TextBox {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  TextBox(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "  \n",
       "  void display(String message, int size, float[] col) {\n",
       "    textSize(size);\n",
       "    fill(col[0],col[1],col[2]);\n",
       "    text(message, location.x, location.y);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Mover {\n",
       "  PVector location;\n",
       "  PVector velocity;\n",
       "  \n",
       "  Mover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    location = new PVector(x_loc, y_loc);\n",
       "    velocity = new PVector(x_vel, y_vel);\n",
       "  }\n",
       "  \n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "  }\n",
       "}\n",
       "\n",
       "class Gamma extends Mover {\n",
       "  Gamma(float x_loc, float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "  }\n",
       "\n",
       "  //creates squiggly lines for a gamma ray\n",
       "  float[] twoLines(float x_val, float y_val, int i) {\n",
       "    //upwards gamma\n",
       "    if (i == 1) {\n",
       "      // return the coordinates of two perpendicular lines\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val-10 },\n",
       "        { x_val+3, y_val-10, x_val+15, y_val-12 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = { coords[1][2], coords[1][3] };\n",
       "      return end;\n",
       "    } else {\n",
       "      float[][] coords = {\n",
       "        { x_val, y_val, x_val+3, y_val+10 },\n",
       "        { x_val+3, y_val+10, x_val+15, y_val+8 }\n",
       "      };\n",
       "\n",
       "      line(coords[0][0], coords[0][1], coords[0][2], coords[0][3]);\n",
       "      line(coords[1][0], coords[1][1], coords[1][2], coords[1][3]);\n",
       "\n",
       "      float[] end = {coords[1][2], coords[1][3]};\n",
       "      return end;\n",
       "    }\n",
       "  }\n",
       "\n",
       "  void drawArrow(float cx, float cy, int len, float angle) {\n",
       "    pushMatrix();\n",
       "    translate(cx, cy);\n",
       "    rotate(radians(angle));\n",
       "    line(0, 0, len, 0);\n",
       "    line(len, 0, len-8, -8);\n",
       "    line(len, 0, len-8, 8);\n",
       "    popMatrix();\n",
       "  }\n",
       "  \n",
       "  void display(int i, int angle) {\n",
       "    stroke(255, 0, 0);\n",
       "    float[] x = twoLines(location.x, location.y, i);\n",
       "    float[] y = twoLines(x[0], x[1], i);\n",
       "    float[] z = twoLines(y[0], y[1], i);\n",
       "    drawArrow(z[0], z[1], 10, angle);\n",
       "  }\n",
       "}\n",
       "\n",
       "float[][] position(float x_val, float y_val, float radius) {\n",
       "  // make it produce the x and y coordinates for the 6 spots around it\n",
       "  float y_dist = sin(radians(30)) * 2 * radius;\n",
       "  float x_dist = cos(radians(30)) * 2 * radius;\n",
       "  \n",
       "  //coords is a list that contains the new coordinates for 6 circles around one circle\n",
       "  float[][] coords = {\n",
       "    { x_val, y_val-(2*radius) },\n",
       "    { x_val+x_dist, y_val-y_dist },\n",
       "    { x_val+x_dist, y_val+y_dist },\n",
       "    { x_val, y_val+(2*radius) },\n",
       "    { x_val-x_dist, y_val+y_dist },\n",
       "    { x_val-x_dist, y_val-y_dist }\n",
       "  };\n",
       "  \n",
       "  return coords;\n",
       "}\n",
       "\n",
       "boolean isItemInArray(float[][] array, float[] item) {\n",
       "    for (int i = 0; i < array.length; i++) {\n",
       "        // This if statement depends on the format of your array\n",
       "        if (array[i][0] == item[0] && array[i][1] == item[1]) {\n",
       "            return true;   // Found it\n",
       "        }\n",
       "    }\n",
       "    return false;   // Not found\n",
       "}\n",
       "\n",
       "//this animation shows how the decceleration of a particle can produce gamma rays\n",
       "\n",
       "// need a large stationary charge -- proton\n",
       "//need an electron moving in a straight line, then need it to bend into an arc\n",
       "//at the moment it bends, emit gamma rays\n",
       "//electron goes off screen\n",
       "\n",
       "import java.lang.*;\n",
       "\n",
       "class BremsstraMover extends Mover {\n",
       "  PVector acceleration;\n",
       "\n",
       "  BremsstraMover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
       "    super(x_loc, y_loc, x_vel, y_vel);\n",
       "    acceleration = new PVector();\n",
       "  }\n",
       "\n",
       "  void update() {\n",
       "    location.add(velocity);\n",
       "    velocity.add(acceleration);\n",
       "  }\n",
       "  \n",
       "  void applyForce(PVector force) {\n",
       "    acceleration = force;\n",
       "  }\n",
       " \n",
       "  PVector attract(BremsstraMover m, float G, float m1, float m2) {\n",
       "    PVector force = PVector.sub(location, m.location);\n",
       "    float distance = force.mag();\n",
       "\n",
       "    distance = constrain(distance, 5.0, 25.0);\n",
       " \n",
       "    force.normalize();\n",
       "    float strength = (G * m1 * m2) / (distance * distance);\n",
       "    force.mult(strength);\n",
       "    return force;\n",
       "  }\n",
       "  \n",
       "  void display(int rad, int col) {\n",
       "    stroke(0);\n",
       "\n",
       "    //blue proton\n",
       "    if (col == 0) {\n",
       "      fill(12, 48, 224);\n",
       "    }\n",
       "    //red electron\n",
       "    else if(col == 1) {\n",
       "      fill(255, 0, 0);\n",
       "    }\n",
       "\n",
       "    ellipse(location.x, location.y, rad, rad);\n",
       "  }\n",
       "}\n",
       "\n",
       "// main function\n",
       "\n",
       "//create stationary proton\n",
       "BremsstraMover proton = new BremsstraMover(350,100,0,0);\n",
       "\n",
       "// create text for positron\n",
       "float px_loc = 305;\n",
       "float py_loc = 120;\n",
       "float px_vel = 0;\n",
       "float py_vel = 00;\n",
       "String p_message = \"Positive Charge\";\n",
       "int p_size = 12;\n",
       "float[] p_col = {12,48,224};\n",
       "TextBox posi_text = new TextBox(px_loc,py_loc, px_vel, py_vel);\n",
       "\n",
       "//create moving electron \n",
       "BremsstraMover electron = new BremsstraMover(8,30,9,2);\n",
       "\n",
       "// create text for electron\n",
       "float ex_loc = 8;\n",
       "float ey_loc = 50;\n",
       "float ex_vel = 9;\n",
       "float ey_vel = 2;\n",
       "String e_message = \"Electron\";\n",
       "int e_size = 12;\n",
       "float[] e_col = {255,0,0};\n",
       "TextBox elec_text = new TextBox(ex_loc,ey_loc, ex_vel, ey_vel);\n",
       "\n",
       "//create gamma rays\n",
       "Gamma g_up = new Gamma(350,100,4.0,-1.0);\n",
       "Gamma g_down = new Gamma(350,100,4.0,1.0);\n",
       "\n",
       "int x = 0;\n",
       "void mousePressed() {\n",
       "  if (x == 0) {\n",
       "    x = 1;\n",
       "  } \n",
       "}\n",
       "\n",
       "void setup() {\n",
       "  size(700,200);\n",
       "  frameRate(35);\n",
       "}\n",
       "\n",
       "void draw() {\n",
       "  background(255);\n",
       "  textSize(20);\n",
       "  fill(0);\n",
       "  text(\"Bremsstrahlung Radiation\", 230, 25);\n",
       "  \n",
       "  if (x == 0) {\n",
       "    proton.display(16,0);\n",
       "    electron.display(8,1);\n",
       "    posi_text.update();\n",
       "    posi_text.display(p_message,p_size,p_col);\n",
       "    elec_text.display(e_message,e_size,e_col);\n",
       "  } else{\n",
       "    posi_text.update();\n",
       "    posi_text.display(p_message,p_size,p_col);\n",
       "    proton.display(16,0);\n",
       "    PVector grav = proton.attract(electron, -9, 5.0, 2);\n",
       "    electron.applyForce(grav);\n",
       "    electron.update();\n",
       "    electron.display(8,1);\n",
       "  \n",
       "    //emit gamma rays when it deccelerates\n",
       "    if (electron.location.x > 288) {\n",
       "      //draw two gamma rays\n",
       "      //up\n",
       "      g_up.update();\n",
       "      g_up.display(1,330);\n",
       "      ////down\n",
       "      g_down.update();\n",
       "      g_down.display(0,20);\n",
       "    }\n",
       "  }\n",
       "}\n",
       "`;\n",
       "  var myCanvas = document.getElementById(\"canvas6\");\n",
       "  var jsCode = Processing.compile(processingCode);\n",
       "  var processingInstance = new Processing(myCanvas, jsCode);\n",
       " </script>\n",
       "<canvas id=\"canvas6\"> </canvas>    \n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "bremsstra_code = \"\"\"\n",
    "//this animation shows how the decceleration of a particle can produce gamma rays\n",
    "\n",
    "// need a large stationary charge -- proton\n",
    "//need an electron moving in a straight line, then need it to bend into an arc\n",
    "//at the moment it bends, emit gamma rays\n",
    "//electron goes off screen\n",
    "\n",
    "import java.lang.*;\n",
    "\n",
    "class BremsstraMover extends Mover {\n",
    "  PVector acceleration;\n",
    "\n",
    "  BremsstraMover(float x_loc,float y_loc, float x_vel, float y_vel) {\n",
    "    super(x_loc, y_loc, x_vel, y_vel);\n",
    "    acceleration = new PVector();\n",
    "  }\n",
    "\n",
    "  void update() {\n",
    "    location.add(velocity);\n",
    "    velocity.add(acceleration);\n",
    "  }\n",
    "  \n",
    "  void applyForce(PVector force) {\n",
    "    acceleration = force;\n",
    "  }\n",
    " \n",
    "  PVector attract(BremsstraMover m, float G, float m1, float m2) {\n",
    "    PVector force = PVector.sub(location, m.location);\n",
    "    float distance = force.mag();\n",
    "\n",
    "    distance = constrain(distance, 5.0, 25.0);\n",
    " \n",
    "    force.normalize();\n",
    "    float strength = (G * m1 * m2) / (distance * distance);\n",
    "    force.mult(strength);\n",
    "    return force;\n",
    "  }\n",
    "  \n",
    "  void display(int rad, int col) {\n",
    "    stroke(0);\n",
    "\n",
    "    //blue proton\n",
    "    if (col == 0) {\n",
    "      fill(12, 48, 224);\n",
    "    }\n",
    "    //red electron\n",
    "    else if(col == 1) {\n",
    "      fill(255, 0, 0);\n",
    "    }\n",
    "\n",
    "    ellipse(location.x, location.y, rad, rad);\n",
    "  }\n",
    "}\n",
    "\n",
    "// main function\n",
    "\n",
    "//create stationary proton\n",
    "BremsstraMover proton = new BremsstraMover(350,100,0,0);\n",
    "\n",
    "// create text for positron\n",
    "float px_loc = 305;\n",
    "float py_loc = 120;\n",
    "float px_vel = 0;\n",
    "float py_vel = 00;\n",
    "String p_message = \"Positive Charge\";\n",
    "int p_size = 12;\n",
    "float[] p_col = {12,48,224};\n",
    "TextBox posi_text = new TextBox(px_loc,py_loc, px_vel, py_vel);\n",
    "\n",
    "//create moving electron \n",
    "BremsstraMover electron = new BremsstraMover(8,30,9,2);\n",
    "\n",
    "// create text for electron\n",
    "float ex_loc = 8;\n",
    "float ey_loc = 50;\n",
    "float ex_vel = 9;\n",
    "float ey_vel = 2;\n",
    "String e_message = \"Electron\";\n",
    "int e_size = 12;\n",
    "float[] e_col = {255,0,0};\n",
    "TextBox elec_text = new TextBox(ex_loc,ey_loc, ex_vel, ey_vel);\n",
    "\n",
    "//create gamma rays\n",
    "Gamma g_up = new Gamma(350,100,4.0,-1.0);\n",
    "Gamma g_down = new Gamma(350,100,4.0,1.0);\n",
    "\n",
    "int x = 0;\n",
    "void mousePressed() {\n",
    "  if (x == 0) {\n",
    "    x = 1;\n",
    "  } \n",
    "}\n",
    "\n",
    "void setup() {\n",
    "  size(700,200);\n",
    "  frameRate(35);\n",
    "}\n",
    "\n",
    "void draw() {\n",
    "  background(255);\n",
    "  textSize(20);\n",
    "  fill(0);\n",
    "  text(\"Bremsstrahlung Radiation\", 230, 25);\n",
    "  \n",
    "  if (x == 0) {\n",
    "    proton.display(16,0);\n",
    "    electron.display(8,1);\n",
    "    posi_text.update();\n",
    "    posi_text.display(p_message,p_size,p_col);\n",
    "    elec_text.display(e_message,e_size,e_col);\n",
    "  } else{\n",
    "    posi_text.update();\n",
    "    posi_text.display(p_message,p_size,p_col);\n",
    "    proton.display(16,0);\n",
    "    PVector grav = proton.attract(electron, -9, 5.0, 2);\n",
    "    electron.applyForce(grav);\n",
    "    electron.update();\n",
    "    electron.display(8,1);\n",
    "  \n",
    "    //emit gamma rays when it deccelerates\n",
    "    if (electron.location.x > 288) {\n",
    "      //draw two gamma rays\n",
    "      //up\n",
    "      g_up.update();\n",
    "      g_up.display(1,330);\n",
    "      ////down\n",
    "      g_down.update();\n",
    "      g_down.display(0,20);\n",
    "    }\n",
    "  }\n",
    "}\n",
    "\"\"\"\n",
    "\n",
    "html_template = \"\"\"\n",
    "<script type=\"text/javascript\" src=\"processing.js\"></script> \n",
    "<script type=\"text/javascript\">\n",
    "  var processingCode = `{}`;\n",
    "  var myCanvas = document.getElementById(\"canvas6\");\n",
    "  var jsCode = Processing.compile(processingCode);\n",
    "  var processingInstance = new Processing(myCanvas, jsCode);\n",
    " </script>\n",
    "<canvas id=\"canvas6\"> </canvas>    \n",
    "\"\"\"\n",
    "\n",
    "html_code = html_template.format(utils_code+bremsstra_code)\n",
    "HTML(html_code)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<center> Figure 11: As the electron comes closer to the positive charge, the electromagnetic force repels its motion. This sudden change in kinetic energy results in the emission of gamma rays.</center>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Physical Properties\n",
    "\n",
    "Gamma rays carry the most energy out of all types of EMR. Any photon carrying approximately 100 keV of energy or more is considered to be a gamma ray. As gamma rays carry no mass or charge, they have a penetrating power significantly higher than alpha or beta particles. Take a look at the image below to see a comparison between the three.\n",
    "\n",
    "<img src=\"https://upload.wikimedia.org/wikipedia/commons/thumb/6/61/Alfa_beta_gamma_radiation_penetration.svg/800px-Alfa_beta_gamma_radiation_penetration.svg.png\" alt=\"radiation penetration\">\n",
    "<center>Image from https://en.wikipedia.org/wiki/File:Alfa_beta_gamma_radiation_penetration.svg</center>\n",
    "<center> Figure 12: Gamma rays have a very high penetrative power, although the likelihood of it being blocked increases with both the thickness and density of the material. </center>\n",
    "\n",
    "\n",
    "### Biological Effects\n",
    "\n",
    "The penetrative strength of gamma rays make them very dangerous to the human body. However, due to the rarity of their occurence, gamma rays should not be a major concern during your everyday life. Most gamma rays are blocked by the many layers of our atmosphere, and any gamma rays formed on Earth are usually held within the containers in which they were formed (nuclear reactors, particle accelerators etc.). "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Exercises\n",
    "\n",
    "Test your knowledge of radiation with the following questions."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'What is it that makes radiation dangerous?'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f33f082d7a0a4c3fbcc1efd76b72396c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(Dropdown(description='Choose One:', options=(' ', 'Radiation is not biodegradable.', 'Ra…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def q_1(val):\n",
    "    if val == \"Radiation has the potential to ionize atoms.\":\n",
    "        display(Latex(\"Correct!\"))\n",
    "        display(Latex(\"Ionized atoms within biological cells can cause damage to the cell itself.\"))\n",
    "    elif val == ' ':\n",
    "        None\n",
    "    else:\n",
    "        display(Latex(\"Try Again!\"))\n",
    "\n",
    "display(\"What is it that makes radiation dangerous?\")\n",
    "\n",
    "a1 = 'Radiation is not biodegradable.'\n",
    "a2 = \"Radiation has the potential to ionize atoms.\"\n",
    "a3 = \"Radiation removes oxygen from the atmosphere.\"\n",
    "interact(q_1, val = widgets.Dropdown(options=[' ',a1 ,a2, a3 ],value = ' ',description = 'Choose One:',disabled = False));\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Which type of radiation has the highest penetrative power?'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "4370dce3280a47ce94ad39b23020f51d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(Dropdown(description='Choose One:', options=(' ', 'Alpha radiation', 'Beta radiation', '…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def q_2(val):\n",
    "    if val == a3:\n",
    "        display(Latex(\"Good stuff!\"))\n",
    "        display(Latex(\"Gamma radiation has no mass or charge, and can therefore go a long way before interacting with matter.\"))\n",
    "    elif val == ' ':\n",
    "        None\n",
    "    else:\n",
    "        display(Latex(\"Try Again!\"))\n",
    "\n",
    "display(\"Which type of radiation has the highest penetrative power?\")\n",
    "\n",
    "a1 = 'Alpha radiation'\n",
    "a2 = \"Beta radiation\"\n",
    "a3 = \"Gamma radiation\"\n",
    "interact(q_2, val = widgets.Dropdown(options=[' ',a1 ,a2, a3 ],value = ' ',description = 'Choose One:',disabled = False));\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Which type of beta decay involves the conversion of a neutron into a proton?'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "885d4eea7f5e4d5bad982f18ddbb2d89",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(Dropdown(description='Choose One:', options=(' ', 'Beta minus', 'Beta plus'), value=' ')…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def q_3(val):\n",
    "    if val == a1:\n",
    "        display(Latex(\"Right on!\"))\n",
    "        display(Latex(\"In beta minus decay, a neutron changes into a proton, ejecting an electron and an antineutrino.\"))\n",
    "    elif val == ' ':\n",
    "        None\n",
    "    else:\n",
    "        display(Latex(\"Try Again!\"))\n",
    "\n",
    "display(\"Which type of beta decay involves the conversion of a neutron into a proton?\")\n",
    "\n",
    "a1 = 'Beta minus'\n",
    "a2 = \"Beta plus\"\n",
    "\n",
    "interact(q_3, val = widgets.Dropdown(options=[' ',a1 ,a2],value = ' ',description = 'Choose One:',disabled = False));\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'An alpha particle is identical to what type of nucleus?'"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "cf550bd875fe4cdbb1c60b9a07b17ea4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(Dropdown(description='Choose One:', options=(' ', 'Lithium', 'Carbon-14', 'Helium-4', 'H…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def q_4(val):\n",
    "    if val == a3:\n",
    "        display(Latex(\"Excellent!\"))\n",
    "        display(Latex(\"A helium-4 nucleus is the exact same: two protons and two neutrons.\"))\n",
    "    elif val == ' ':\n",
    "        None\n",
    "    else:\n",
    "        display(Latex(\"Try Again!\"))\n",
    "\n",
    "display(\"An alpha particle is identical to what type of nucleus?\")\n",
    "\n",
    "a1 = 'Lithium'\n",
    "a2 = \"Carbon-14\"\n",
    "a3 = \"Helium-4\"\n",
    "a4 = \"Hydrogen\"\n",
    "interact(q_4, val = widgets.Dropdown(options=[' ',a1 ,a2, a3, a4],value = ' ',description = 'Choose One:',disabled = False));\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Conclusion\n",
    "\n",
    "Upon their discovery, Ernest Rutherford named these three types of radiation according to the first three letters of the greek alphabet. He chose the names based on their respective penetrative power, with alpha being the weakest, then beta, followed by gamma.\n",
    "\n",
    "Different forms of radiation can be both a useful tool, and a potential hazard. In any case, analyzing the properties of radiation allows us to determine the circumstances of its creation, and we use this information to learn about the objects that form it. There are fields of astronomy that are tailored to the analysis of specific forms of radiation, such as gamma, infrared, and radio, that unveil entirely new perspectives on various objects in the universe.\n",
    "\n",
    "\n",
    "<img src=\"http://cdn.eso.org/images/screen/eso1205d.jpg\" alt=\"Drawing\" style=\"width: 750px;\"/>\n",
    "<center>Image from https://www.eso.org/public/images/eso1205d</center>\n",
    "<center> Figure 13: Above are two images of the Helix Nebula. The one on the left is an image captured using infrared light, while the one on the right is captured in visible light. </center>\n",
    "\n",
    "On the other hand, radiation can be used to cause widespread devastation. There are many areas in the world that are still unsafe due to the residual radiation caused by nuclear weapons, or nuclear waste. Therefore, it is important that the world becomes aware of the dangers associated with radiation."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "[![Callysto.ca License](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-bottom.jpg?raw=true)](https://github.com/callysto/curriculum-notebooks/blob/master/LICENSE.md)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
